<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/
/**
	
	@brief adminPage module class
	
	La classe qui se charge de gerer le menu de la partie administration
*/
class adminPage
{
	/**
	open<br/>
	
	<strong>FR</strong>	Ouvre une page HTML de la partie administration.<br/>
	<strong>EN</strong>	Open a HTML page of the administration part
	
	@param title <strong>string</strong>	Title page
	@param head	 <strong>string</strong>	additional HTML to be put in the header
	*/
	function open($title='',$head='')
	{
		global $puntal, $lang_admin, $common_message, $common_warning, $common_error;
			
		# Assignation des ventuelles erreurs
		if ($puntal->err->hasError())
			$common_error = $puntal->err->getError();
		
		# Dbut affichage
		header('Content-Type: text/html; charset='.__('lang_encoding'));
		
		echo
		'<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" '.
		' "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'."\n".
		'<html xmlns="http://www.w3.org/1999/xhtml">'."\n".
		'<head>'."\n".
		'<meta http-equiv="Content-Type" content="text/html; charset='.__('lang_encoding').'" />'."\n".
		'<title>'.($title != '' ? $title.' - ' : '').'Puntal '.pt_version.'</title>'."\n".
		adminPage::jsLoadIE7().
		'<link rel="stylesheet" type="text/css" href="style/style.css" />'."\n".
		adminPage::jsCommon()."\n".
		
		// afin de rendre le menu plus "accessible" 
		// je mets en commentaire ce morceau de javascript.
		
		/*'<script type="text/javascript">'."\n".
		'//<![CDATA['."\n".
		'$(function() {'."\n".
		'	'.$GLOBALS['menu']->drawJs()."\n".
		'});'."\n".
		'//]]>'."\n".
		'</script>'."\n\n".*/
		$head."\n\n";
		
		# --BEHAVIOR-- adminHeadHTML
		$puntal->callBehavior('adminHeadHTML');
		
		echo
		'</head>'."\n".
		'<body>'."\n".
		'<div id="contener">'."\n".
		'<div id="top">'."\n".
		'	<h1>Puntal <span class="version">'.pt_version.'</span></h1>'."\n".
		'	<div id="prelude">'."\n".
		'		<p id="accesslinks">'."\n".
		'			<a href="#content">'.__('Go to content').'</a> | '."\n".
		'			<a href="#sidebar">'.__('Go to menu').'</a>'."\n".
		'		</p>'."\n".
		'		<p id="headlinks">'."\n".
		'			<a href="'.pt_portal_url.'" id="backportal">'.__('See portal').'</a> | '."\n".
		'			<a href="'.pt_portal_url.'logout" id="logout">'.__('Logout').'</a>'."\n".
		'		</p>'."\n".
		'	</div>'."\n".
		'</div>'."\n".
		'<div id="page">'."\n".
		'<div id="content">'."\n";
		
		if (!empty($common_message))
		{
			echo 
			'<div class="messagebox">'.
			'<h2>'.__('Message').'</h2><p>'.
			$common_message.'</p></div>';
		}
		
		if (!empty($common_warning))
		{
			echo 
			'<div class="warningbox">'.
			'<h2>'.__('Warning').'</h2><p>'.
			$common_warning.'</p></div>';
		}
		
		if (!empty($common_error))
		{
			echo 
			'<div class="errorbox">'.
			'<h2>'.__('Error').'</h2><p>'.
			$common_error.'</p></div>';
		}
		
		# --BEHAVIOR-- adminContentTopHTML
		$puntal->callBehavior('adminContentTopHTML');
	}
	
	
	/**
	close<br/>
	
	<strong>FR</strong>	Ferme une page HTML de la partie administration.<br/>
	<strong>EN</strong>	Close a HTML page of the administration part
	*/
	
	function close()
	{
		global $puntal, $lang_admin;
		
		$page = basename($_SERVER['PHP_SELF']);
		
		# --BEHAVIOR-- adminContentBottomHTML
		$puntal->callBehavior('adminContentBottomHTML');
		
		echo
		'</div><!-- #content -->'."\n".
		'</div><!-- #page -->'."\n\n".
		'<div id="sidebar">'."\n\n";
		
		# --BEHAVIOR-- adminBeforeMenuHTML
		$puntal->callBehavior('adminBeforeMenuHTML');
		
		echo $GLOBALS['menu']->drawMenus()."\n\n";
		
		# --BEHAVIOR-- adminAfterMenuHTML
		$puntal->callBehavior('adminAfterMenuHTML');
		
		echo
		'</div><!-- #sidebar -->'."\n".
		'<div class="clearer"><!-- --></div>'."\n\n".
		'<div id="footer">'.
		'	<p><span>'.__('Powered by').' <a href="http://www.puntal.fr/">Puntal</a> '.pt_version.'</span>	&copy; Copyright 2005-2007 '.__('Puntal Team');
		
		if (DEBUG > 0) 
		{
			list($usec, $sec) = explode(' ', microtime());
			$pt_time_diff = sprintf('%.3f', ((float)$usec + (float)$sec) - $GLOBALS['pt_start']);
			
			echo '<br /> [ ';
			printf(__('Generated in'), $pt_time_diff);
			echo ' - ';
			printf(__('%s queries executed'),$GLOBALS['con']->nb_q());
			echo ' ]';
		}
		
		echo "</p>\n</div><!-- #footer -->\n</div><!-- #contener -->\n";
		
		if (DEBUG > 1) 
		{
			foreach ($GLOBALS['puntal']->con->queries as $q)
				echo '<p>'.$q.'</p>';
		}
		
		echo "</body>\n</html>";
		
		$GLOBALS['con']->close();
		exit;
	}
	
	
	/**
	fatalErrorPage<br/>

	<strong>FR</strong>	Affiche une page d'erreur fatale.<br/>
	<strong>EN</strong>	Display the fatale error page
	
	@param message	 <strong>string</strong>	error message associated
	*/
	function fatalErrorPage($message)
	{
		adminPage::open(__('Error'));
		echo '<h2 class="first"><img src="style/img/ko.png" alt="" /> '.__('Error').'</h2>';
		echo '<p>'.$message.'</p>';
		adminPage::close();
		exit;
	}
	
	/**
	jsLoad<br/>

	<strong>FR</strong>	charge un JavaScript<br/>
	<strong>EN</strong>	Load a JavaScript
	
	@param src	 <strong>string</strong>	the url to the JavaScript
	*/	
	function jsLoad($src)
	{
		return '<script type="text/javascript" src="'.html::escapeHTML($src).'"></script>'."\n";
	}
	
	/**
	jsVar<br/>

	<strong>FR</strong>	alloue une variable en JavaScript<br/>
	<strong>EN</strong>	Init a var in a JavaScript
	
	@param n	 <strong>string</strong>	name of the var
	@param v	 <strong>string</strong>	value of the var
	*/	
	
	function jsVar($n,$v)
	{
		return $n." = '".html::escapeJS($v)."';\n";
	}
	
	/**
	jsCommon<br/>

	<strong>FR</strong>	charge les scripts JavaScript commun<br/>
	<strong>EN</strong>	Load the common JavaScript
	*/	
	function jsCommon()
	{
		return
		adminPage::jsLoad('js/jquery/jquery.js').
		adminPage::jsLoad('js/jquery/jquery.cookie.js').
		adminPage::jsLoad('js/jquery/jquery.bgFade.js').
		adminPage::jsLoad('js/common.js').
		
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		adminPage::jsVar('puntal.msg.select_all',
			__('select all')).
		adminPage::jsVar('puntal.msg.invert_sel',
			__('invert select')).
		"\n//]]>\n".
		"</script>\n";
	}
	
	/**
	jsLoadIE7<br/>

	<strong>FR</strong>	charge les scripts JavaScript pour corriger des pb IE7<br/>
	<strong>EN</strong>	Load the fixed IE7  JavaScript
	*/	
	function jsLoadIE7()
	{
		return
		'<!--[if lt IE 7]>'."\n".
		adminPage::jsLoad('js/ie7/ie7-standard-p.js').
		'<link rel="stylesheet" type="text/css" href="style/iesucks.css" />'."\n".
		'<![endif]-->'."\n";
	}
	
	/**
	jsPageTabs<br/>

	<strong>FR</strong>	charge les scripts JavaScript pour gerer des onglets<br/>
	<strong>EN</strong>	Load the page tab  JavaScript
	
	@param default	 <strong>string</strong>	select the default tab
	*/	
	function jsPageTabs($default=null)
	{
		if ($default)
			$default = "'".html::escapeJS($default)."'";
		
		return
		adminPage::jsLoad('js/jquery/jquery.pageTabs.js').
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		"\$(function() {\n".
		"	\$.pageTabs(".$default.");\n".
		"});\n".
		"\n//]]>\n".
		"</script>\n";
	}
	
	/**
	jsDatePicker<br/>

	<strong>FR</strong>	charge les scripts JavaScript pour gerer une popup de calendrier<br/>
	<strong>EN</strong>	Load the popup calendar JavaScript
	*/		
	function jsDatePicker()
	{
		return
		'<link rel="stylesheet" type="text/css" href="style/date-picker.css" />'."\n".
		adminPage::jsLoad('js/date-picker.js').
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		
		"datePicker.prototype.months[0] = '".html::escapeJS(__('January'))."'; ".
		"datePicker.prototype.months[1] = '".html::escapeJS(__('February'))."'; ".
		"datePicker.prototype.months[2] = '".html::escapeJS(__('March'))."'; ".
		"datePicker.prototype.months[3] = '".html::escapeJS(__('April'))."'; ".
		"datePicker.prototype.months[4] = '".html::escapeJS(__('May'))."'; ".
		"datePicker.prototype.months[5] = '".html::escapeJS(__('June'))."'; ".
		"datePicker.prototype.months[6] = '".html::escapeJS(__('July'))."'; ".
		"datePicker.prototype.months[7] = '".html::escapeJS(__('August'))."'; ".
		"datePicker.prototype.months[8] = '".html::escapeJS(__('September'))."'; ".
		"datePicker.prototype.months[9] = '".html::escapeJS(__('October'))."'; ".
		"datePicker.prototype.months[10] = '".html::escapeJS(__('November'))."'; ".
		"datePicker.prototype.months[11] = '".html::escapeJS(__('December'))."'; ".
	
		"datePicker.prototype.days[0] = '".html::escapeJS(__('Monday'))."'; ".
		"datePicker.prototype.days[1] = '".html::escapeJS(__('Tuesday'))."'; ".
		"datePicker.prototype.days[2] = '".html::escapeJS(__('Wednesday'))."'; ".
		"datePicker.prototype.days[3] = '".html::escapeJS(__('Thursday'))."'; ".
		"datePicker.prototype.days[4] = '".html::escapeJS(__('Friday'))."'; ".
		"datePicker.prototype.days[5] = '".html::escapeJS(__('Saturday'))."'; ".
		"datePicker.prototype.days[6] = '".html::escapeJS(__('Sunday'))."'; ".
		
		"datePicker.prototype.img_src = 'style/img/ico_calendar.png'; ".
		
		"datePicker.prototype.close_msg = '".html::escapeJS(__('Close'))."'; ".
		"datePicker.prototype.now_msg = '".html::escapeJS(__('Now'))."'; ".
		
		"\n//]]>\n".
		"</script>\n";
	}
	
	/**
	jsToolBar<br/>

	<strong>FR</strong>	charge les scripts JavaScript pour gerer une barre d'outil<br/>
	<strong>EN</strong>	Load the toolbar JavaScript
	*/		
	function jsToolBar()
	{
		return
		'<link rel="stylesheet" type="text/css" href="style/jsToolBar/jsToolBar.css" />'.
		'<script type="text/javascript" src="js/jsToolBar/jsToolBar.js"></script>'.
		'<script type="text/javascript" src="js/jsToolBar/jsToolBar.wysiwyg.js"></script>'.
		'<script type="text/javascript" src="js/jsToolBar/jsToolBar.dotclear.js"></script>'.
		'<script type="text/javascript">'."\n".
		"//<![CDATA[\n".
		"jsToolBar.prototype.dialog_url = 'popup.php'; ".
		"jsToolBar.prototype.iframe_css = '".
			'body{'.
				'font: x-small/1.5em Verdana,Geneva,sans-serif;'.
				'color : #000;'.
				'background: #f9f9f9;'.
				'margin: 0;'.
				'padding : 2px;'.
				'border: none;'.
			'}'.
			'pre, code, kbd, samp {'.
				'font-family:"Courier New",Courier,monospace;'.
				'font-size : 1.1em;'.
			'}'.
			'code {'.
				'color : #666;'.
				'font-weight : bold;'.
			'}'.
			'body > p:first-child {'.
				'margin-top: 0;'.
			'}'.
		"'; ".
		"jsToolBar.prototype.base_url = '".html::escapeJS(puntal::getHost())."'; ".
		"jsToolBar.prototype.switcher_visual_title = '".html::escapeJS(__('visual'))."'; ".
		"jsToolBar.prototype.switcher_source_title = '".html::escapeJS(__('source'))."'; ".
		"jsToolBar.prototype.legend_msg = '".
		html::escapeJS(__('You can use the following shortcuts to format your text.'))."'; ".
		"jsToolBar.prototype.elements.strong.title = '".html::escapeJS(__('Strong emphasis'))."'; ".
		"jsToolBar.prototype.elements.em.title = '".html::escapeJS(__('Emphasis'))."'; ".
		"jsToolBar.prototype.elements.ins.title = '".html::escapeJS(__('Inserted'))."'; ".
		"jsToolBar.prototype.elements.del.title = '".html::escapeJS(__('Deleted'))."'; ".
		"jsToolBar.prototype.elements.quote.title = '".html::escapeJS(__('Inline quote'))."'; ".
		"jsToolBar.prototype.elements.code.title = '".html::escapeJS(__('Code'))."'; ".
		"jsToolBar.prototype.elements.br.title = '".html::escapeJS(__('Line break'))."'; ".
		"jsToolBar.prototype.elements.blockquote.title = '".html::escapeJS(__('Blockquote'))."'; ".
		"jsToolBar.prototype.elements.pre.title = '".html::escapeJS(__('Preformated text'))."'; ".
		"jsToolBar.prototype.elements.ul.title = '".html::escapeJS(__('Unordered list'))."'; ".
		"jsToolBar.prototype.elements.ol.title = '".html::escapeJS(__('Ordered list'))."'; ".
		
		"jsToolBar.prototype.elements.link.title = '".html::escapeJS(__('Link'))."'; ".
		"jsToolBar.prototype.elements.link.href_prompt = '".html::escapeJS(__('URL?'))."'; ".
		"jsToolBar.prototype.elements.link.hreflang_prompt = '".html::escapeJS(__('Language?'))."'; ".
		
		"jsToolBar.prototype.elements.img.title = '".html::escapeJS(__('External image'))."'; ".
		"jsToolBar.prototype.elements.img.src_prompt = '".html::escapeJS(__('URL?'))."'; ".
		
		"jsToolBar.prototype.elements.img_select.title = '".html::escapeJS(__('Image chooser'))."'; ".
		
		"jsToolBar.prototype.elements.img_select.disabled = true;\n".

		"\n//]]>\n".
		"</script>\n";
	}

	/**
	jsToolMan<br/>

	<strong>FR</strong>	charge les scripts JavaScript pour gerer le drag and drop<br/>
	<strong>EN</strong>	Load the drag and drop JavaScript
	*/			
	function jsToolMan()
	{
		return
		adminPage::jsLoad('js/tool-man/core.js').
		adminPage::jsLoad('js/tool-man/events.js').
		adminPage::jsLoad('js/tool-man/css.js').
		adminPage::jsLoad('js/tool-man/coordinates.js').
		adminPage::jsLoad('js/tool-man/drag.js').
		adminPage::jsLoad('js/tool-man/dragsort.js').
		adminPage::jsLoad('js/dragsort-tablerows.js');
	}	


	/**
	openPopup<br/>

	<strong>FR</strong>	ouvre une popup<br/>
	<strong>EN</strong>	open a popup window
	
	@param title <strong>string</strong>	the title of the popup
	@param head	 <strong>string</strong>	the additionnal 'things' to be put in the header
	*/		
	function openPopup($title='', $head='')
	{
		
		# Display
		header('Content-Type: text/html; charset='.__('lang_encoding'));
		echo		
		'<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" '.
		' "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'."\n".
		'<html xmlns="http://www.w3.org/1999/xhtml"> '."\n".
		"<head>\n".
		'  <meta http-equiv="Content-Type" content="text/html; charset=""'.__('lang_encoding').'" />'."\n".
		'<title>'.($title != '' ? $title.' - ' : '').'Puntal '.pt_version.'</title>'."\n".
		
		adminPage::jsLoadIE7().
		'<link rel="stylesheet" type="text/css" href="style/style.css" />'."\n".
		adminPage::jsCommon()."\n".		
		$head.
		"</head>\n".
		'<body id="dotclear-admin" class="popup">'."\n".
		
		'<div id="top"><h1>Puntal <span class="version">'.pt_version.'</span></h1>'."\n".

		'<div id="page">'."\n".
		'<div id="content">'."\n";
		
	}

	/**
	closePopup<br/>

	<strong>FR</strong>	ferme une popup<br/>
	<strong>EN</strong>	close a popup window
	*/	
	function closePopup() {
		
		echo
		"</div>\n".		// End of #content
		"</div>\n".	// End of #main
		'</body></html>';
		
	}
		
}

/**
	
	@brief adminMenu module class
	
	<strong>FR</strong> La classe qui se charge de construire le menu de la partie administration<br/>
	<strong>EN</strong> the class in charge to build the administration menu
*/
class adminMenu
{
	var $menus;

	/**
	adminMenu<br/>

	<strong>FR</strong>	constructeur<br/>
	<strong>EN</strong>	constructor
	*/		
	function adminMenu()
	{
		$this->menus = array();
	}

	/**
	newMenu<br/>

	<strong>FR</strong>	gestionnaire de menu<br/>
	<strong>EN</strong>	menu manager
	
	@param id <strong>integer</strong>	the id of the menu
	@param title	 <strong>string</strong>	the title of the menu
	@param position	 <strong>string</strong>	the position of the menu	
	*/
	function newMenu($id,$title='',$position=1000)
	{
		$this->menus[$id] = array(
			'title' => $title,
			'items' => array(),
			'position' => $position
		);
	}

	/**
	addItem<br/>

	<strong>FR</strong>	ajout d'une option dans le menu<br/>
	<strong>EN</strong>	add an item
	
	@param id <strong>integer</strong>	the id of the menu
	@param title	 <strong>string</strong>	the title item
	@param url	 <strong>string</strong>	the url of the item
	@param position	 <strong>string</strong>	the position of the item
	@param active	 <strong>boolean</strong>	activated item ?
	@param show	 <strong>boolean</strong>	show the item ?	
	@param id_item	 <strong>boolean</strong>	the id of the item
	*/	
	function addItem($id, $title, $url, $active, $show=true, $id_item=NULL)
	{
		if ($show)
		{
			$this->menus[$id]['items'][] =
			'<li'.(($active) ? ' class="actif"' : '').
			(($id_item) ? ' id="'.$id_item.'"' : '').
			'><a href="'.$url.'">'.$title.'</a></li>';
		}
	}

	/**
	drawJs<br/>

	<strong>FR</strong>	le javascript qui gere l'affichage des menus qui se plient/deplient<br/>
	<strong>EN</strong>	javascript that manage the expand/collapse dispay of the menus
	*/		
	function drawJs()
	{
		$res = '';
		
		foreach ($this->menus as $id=>$menu)
		{
			$res .= 
			"\n$('#menu_".$id."').prev().toggleWithLegend($('#menu_".$id."'),{
				cookie: 'pt_menu_".$id."',
				img_on: 'style/img/blockmenu_expand.png',
				img_off: 'style/img/blockmenu_collapse.png'
			});\n";
		}
		
		return $res;
	}

	/**
	drawMenus<br/>

	<strong>FR</strong>	affiche les menus<br/>
	<strong>EN</strong>	display the menus
	*/	
	function drawMenus()
	{
		uasort($this->menus,array($this,'sortMenus'));
		
		$res = "\n";
		
		foreach ($this->menus as $id=>$menu)
		{
			if ($menu['title'] != '')
				$res .= "<h2>".$menu['title']."</h2>\n";
			
			$res .= "<div id=\"menu_".$id."\">\n\t<ul>\n\t\t";
			
			if (count($menu['items']) > 0)
				$res .= implode("\n\t\t", $menu['items']);
			else
				$res .= '<li>&nbsp;</li>';
			
			$res .= "\n\t</ul>\n</div>\n\n";
		}
		
		return $res;
	}

	/**
	sortMenus<br/>

	<strong>FR</strong>	trie le menu<br/>
	<strong>EN</strong>	sort the menu
	
	@param a <strong>string</strong> the first thing to compare
	@param b <strong>string</strong> the second thing to compare
	*/	
	function sortMenus($a,$b)
	{
		if ($a['position'] == $b['position'])
			return strcasecmp($a['title'],$b['title']);
		
		return ($a['position'] < $b['position']) ? -1 : 1;
	}
}

	
/**
checkPerm<br/>

<strong>FR</strong>Vrifie une permission pour l'utilisateur courant.<br/>
<strong>EN</strong>Check the permission of the current user

@param on <strong>string</strong> 
@return <strong>boolean</strong>
*/
function checkPerm($on='')
{
	global $puntal;
	
	if ($puntal->user['g_id'] == PUN_ADMIN)
		return true;
	elseif (in_array($on, $GLOBALS['pt_perms'][$puntal->user['g_id']]))
		return true;
	else
		return false;
}


/**
logIt<br/>

<strong>FR</strong> Ecrit dans le journal admin.
<strong>FR</strong> Write in the admin Log

@param text <strong>string<strong> 		Log text
@param code <strong>integer<strong>		Log level
*/
function logIt($text='', $code=0)
{
	global $puntal;
	
	$sql =  "INSERT INTO ".DB_PREFIX."pt_log ".
			"( user_id, user_name, user_ip, date, log, code ) ".
			"VALUES (".
			"'".$puntal->user['id']."', '".addslashes($puntal->user['username'])."', '".$_SERVER['REMOTE_ADDR']."', '".date('Y-m-d H:i:s')."', '".$puntal->con->escapeStr($text)."', '".(int)$code."'".
			");";
	
	$result = $puntal->con->execute($sql) or $puntal->err->fatalError('Impossible d\'ajouter log dans la table pt_log', $puntal->con->error());
	return true;
}


/**
updateCacheLatestRelease<br/>

<strong>FR</strong> Ecrit le fichier cache de dernire version d'un lment.
<strong>FR</strong> Write he cache file of the last version of a module

@param url	<strong>string</strong>			URL where to check the latest version
@param cache_file <strong>string</strong> 	Cache filename
@return <strong>boolean</strong> 
*/
function updateCacheLatestRelease($url='',$cache_file='')
{
	global $puntal;
	
	# Get latest release from puntal.fr
	if (!ini_get('allow_url_fopen'))
	{
		$puntal->err->setError(__('Unable to check the updates as long as allow_url_fopen is disable on this system.'));
		return false;
	}
	
	$fp = @fopen($url, 'r');
	$latest_version = trim(@fread($fp, 16));
	@fclose($fp);
	
	if ($latest_version == '')
	{
		$puntal->err->setError(sprintf(__('Checking for an update of "%s" failed for an unknown reason.'),$cache_file));
		$latest_version = 0;
	}
	
	# Write cache
	$fh = @fopen(PT_CACHE_PATH.'/latest_versions/'.$cache_file, 'wb');
	if (!$fh)
	{
		$puntal->err->setError('Impossible d\'crire le fichier cache de dernire version dans le rpertoire cache. Veuillez vous assurer que PHP a l\'accs en criture au rpertoire "/cache/latest_versions" de Puntal.');
		return false;
	}
	fwrite($fh, $latest_version);
	fclose($fh);
	
	return $latest_version;
}


/**
compare_version<br/>

<strong>FR</strong> Compare 2 versions et contourne un bug de version_compare qui ne gere pas les espaces dans le numero de version ni RC   
<strong>FR</strong> Compare 2 version - workarround of version_compare that does not manage the space in the version numbero nor RC.

@param v1 <strong>string</strong>	version 1
@param v2 <strong>string</strong> 	version 2
@return compared version <strong>string</strong> 
*/
function compare_version($v1,$v2)
{
	$v1 = str_replace(' ', '.',str_replace('rc', 'RC',strtolower($v1)));
	$v2 = str_replace(' ', '.',str_replace('rc', 'RC',strtolower($v2)));

	return version_compare($v1,$v2);
}

?>