<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

# Load installation locales
if (isset($puntal))
	l10n::set(dirname(__FILE__).'/../../locales/'.$puntal->user['language'].'/install');
elseif (isset($ses))
	l10n::set(dirname(__FILE__).'/../../locales/'.$ses->f('lang').'/install');
else
	l10n::set(dirname(__FILE__).'/../../locales/English/install');

class installModule
{
	var $con;
	var $err;
	var $settings;
	var $module;
	var $check;	
	
	
	/**
	@function installModule
	
	*/
	function installModule(&$con,&$err,&$settings,&$module)
	{
		$this->con =& $con;
		$this->err =& $err;
		$this->settings =& $settings;
		$this->module =& $module;
		$this->check = new checklist();
	}	
	
	
	/* Fonction "Pilotes"
	----------------------------------------------------------*/
	
	/**
	@function install
	
	*/
	function install($scheme,$params,$dir=array())
	{
		$this->installDB($scheme);
		$this->installParams($params,'mod_'.$this->module['id']);
		
		if (!empty($dir))
			$this->installDirs($dir);
		
		$this->settings->setNamespace('puntal');
		$this->settings->put('pt_mod_'.$this->module['id'], true, 'boolean');
		$this->settings->put('pt_mod_'.$this->module['id'].'_version', $this->module['version'], 'string');
		$this->settings->setNamespace('');
	}
	
	
	/**
	@function uninstall
	
	*/
	function uninstall($scheme,$params,$dir=array())
	{
		$this->uninstallDB($scheme);
		$this->uninstallParams($params,'mod_'.$this->module['id']);
		
		if (!empty($dir))
			$this->uninstallDirs($dir);
		
		$this->settings->setNamespace('puntal');
		$this->settings->drop('pt_mod_'.$this->module['id']);
		$this->settings->drop('pt_mod_'.$this->module['id'].'_version');
		$this->settings->setNamespace('');
	}
	
	
	/**
	@function update
	
	*/
	function update($scheme,$params)
	{
		$this->uninstallDB($scheme);
		$this->uninstallParams($params,'mod_'.$this->module['id']);
		
		$this->settings->setNamespace('puntal');
		$this->settings->put('pt_mod_'.$this->module['id'].'_version', $this->module['version'], 'string');
		$this->settings->setNamespace('');
	}
		
	
	/* Base de donnes
	----------------------------------------------------------*/
	
	/**
	@function installDB
	
	*/
	function installDB($scheme)
	{
		if (!is_array($scheme))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid installation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$scheme', 'installDB()'));
			return false;
		}
			
		$this->_doDb($scheme);
		return true;
	}
	
	
	/**
	@function uninstallDB
	
	*/
	function uninstallDB($scheme)
	{
		if (!is_array($scheme))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid installation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$scheme', 'uninstallDB()'));
			return false;
		}
		
		$this->_doDb($scheme);
		return true;
	}
	
	
	/**
	@function updateDB
	
	*/
	function updateDB($scheme)
	{
		if (!is_array($scheme))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid installation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$scheme', 'updateDB()'));
			return false;
		}
		
		$this->_doDb($scheme);
		return true;
	}
	
	
	/**
	@function _doDb
	
	*/
	function _doDb($scheme)
	{
		foreach ($scheme as $sql)
		{
			if (empty($sql['action']) || 
				($sql['action'] != 'add' && 
				 $sql['action'] != 'update' && 
				 $sql['action'] != 'delete'))
			{
				$this->err->setError(__('There is an invalid "action" parameter.'));
				return false;
			}
			
			switch ($sql['action'])
			{
				case 'add':
					$this->_addSql($sql);
					break;
				
				case 'update':
					$this->_updateSql($sql);
					break;
				
				case 'delete':
					$this->_deleteSql($sql);
					break;
			}
		}
	}
	
	
	/**
	@function _addSql
	
	*/
	function _addSql($sql)
	{
		$this->check->addItem(
			sprintf(__('Create <em>%s</em> table'),$sql['table']),
			$this->con->execute($sql['query']),
			sprintf(__('Table <em>%s</em> successfully created'),$sql['table']),
			sprintf(__('Unable to create <em>%s</em> table'),$sql['table']).
			' '.__('Database reported:').' '.$this->con->error()
		);	
	}
	
	
	/**
	@function _updateSql
	
	*/
	function _updateSql($sql)
	{
		$this->check->addItem(
			sprintf(__('Update <em>%s</em> table'),$sql['table']),
			$this->con->execute($sql['query']),
			sprintf(__('Table <em>%s</em> successfully updated'),$sql['table']),
			sprintf(__('Unable to update <em>%s</em> table'),$sql['table']).
			' '.__('Database reported:').' '.$this->con->error()
		);	
	}
	
	
	/**
	@function _deleteSql
	
	*/
	function _deleteSql($sql)
	{
		$this->check->addItem(
			sprintf(__('Delete <em>%s</em> table'),$sql['table']),
			$this->con->execute($sql['query']),
			sprintf(__('Table <em>%s</em> successfully deleted'),$sql['table']),
			sprintf(__('Unable to delete <em>%s</em> table'),$sql['table']).
			' '.__('Database reported:').' '.$this->con->error()
		);	
	}
	
	
	/* Paramtres de configuration
	----------------------------------------------------------*/
	
	/**
	@function installParams
	
	*/
	function installParams($params,$ns='')
	{
		if (!is_array($params))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid installation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$params', 'installParams()'));
			return false;
		}
				
		$this->settings->setNamespace($ns);
		$this->_doParams($params);
		$this->settings->setNamespace('');
	}	
	
	
	/**
	@function updateParams
	
	*/
	function updateParams($params,$ns='')
	{
		if (!is_array($params))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid update process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$params', 'updateParams()'));
			return false;
		}
				
		$this->settings->setNamespace($ns);
		$this->_doParams($params);
		$this->settings->setNamespace('');
	}
	
	
	/**
	@function uninstallParams
	
	*/
	function uninstallParams($params,$ns='')
	{
		if (!is_array($params))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid uninstallation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$params', 'uninstallParams()'));
			return false;
		}
				
		$this->settings->setNamespace($ns);
		$this->_doParams($params);
		$this->settings->setNamespace('');
	}
	
	
	/**
	@function doParams
	
	*/
	function _doParams($params)
	{
		foreach ($params as $param)
		{
			if (empty($param['action']) || 
				($param['action'] != 'add' && 
				 $param['action'] != 'update' && 
				 $param['action'] != 'delete'))
			{
				$this->err->setError(__('There is an invalid "action" parameter.'));
				return false;
			}
			
			switch ($param['action'])
			{
				case 'add':
					$this->_addParam($param);
					break;
				
				case 'update':
					$this->_updateParam($param);
					break;
				
				case 'delete':
					$this->_deleteParam($param);
					break;
			}
		}
	}
	
	
	/**
	@function _addParam
	
	*/
	function _addParam($param)
	{
		$this->check->addItem(
			sprintf(__('Add <em>%s</em> setting'),$param['name']),
			$this->settings->put($param['name'], $param['init'], $param['type']),
			sprintf(__('Setting <em>%s</em> successfully added'),$param['name']),
			sprintf(__('Unable to add <em>%s</em> setting'),$param['name'])
		);
	}
	
	
	/**
	@function _updateParam
	
	*/
	function _updateParam($param)
	{
		$this->check->addItem(
			sprintf(__('Update <em>%s</em>setting'),$param['name']),
			$this->settings->put($param['name'], $param['init'], $param['type']),
			sprintf(__('Setting <em>%s</em> successfully updated'),$param['name']),
			sprintf(__('Unable to update <em>%s</em> setting'),$param['name'])
		);
	}
	
	
	/**
	@function _deleteParam
	
	*/
	function _deleteParam($param)
	{
		$this->check->addItem(
			sprintf(__('Delete <em>%s</em> setting'),$param['name']),
			$this->settings->drop($param['name']),
			sprintf(__('Setting <em>%s</em> successfully deleted'),$param['name']),
			sprintf(__('Unable to delete <em>%s</em> setting'),$param['name'])
		);
	}
	
	
	/* Dossiers
	----------------------------------------------------------*/
	
	/**
	@function installDirs
	
	*/
	function installDirs($dirs)
	{
		if (!is_array($dirs))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid installation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$dirs', 'installDir()'));
			return false;
		}
		
		foreach ($dirs as $path)
			$this->makeDir($path);
		
		return true;
	}
	
	/**
	@function uninstallDirs
	
	*/
	function uninstallDirs($dirs)
	{
		if (!is_array($dirs))
		{
			$this->err->setError(sprintf(__('The module %s does not have a valid uninstallation process'),__($this->module['name'])).'<br />'.sprintf(__('%s must be valid array in %s function'), '$dirs', 'uninstallDir()'));
			return false;
		}
		
		foreach ($dirs as $path)
			$this->removeDir($path);
		
		return true;
	}
	
	/**
	@function makeFile
	
	*/
	function makeFile($path,$content)
	{
		$this->check->addItem(
			sprintf(__('Create <em>%s</em> file'),$path),
			$this->_createFile($path,$content),
			sprintf(__('File <em>%s</em> successfully created'),$path),
			sprintf(__('Unable to create <em>%s</em> file'),$path)
		);
	}
	function _createFile($path,$content)
	{
		if (($fp = fopen($path,'w')) !== false)
		{
			fwrite($fp,$content,strlen($content));
			fclose($fp);
			chmod($path,fileperms(dirname($path)) & ~0111);
			return true;
		}
		else
			return false;
	}
	
	/**
	@function makeDir
	
	*/
	function makeDir($path)
	{
		$this->check->addItem(
			sprintf(__('Create <em>%s</em> directory'),$path),
			files::makeDir($path),
			sprintf(__('Directory <em>%s</em> successfully created'),$path),
			sprintf(__('Unable to create <em>%s</em> directory'),$path)
		);
	}
		
	/**
	@function removeDir
	
	*/
	function removeDir($path)
	{
		$this->check->addItem(
			sprintf(__('Delete <em>%s</em> directory'),$path),
			$this->_delDir($path),
			sprintf(__('Directory <em>%s</em> successfully deleted'),$path),
			sprintf(__('Unable to delete <em>%s</em> directory'),$path)
		);
	}
	
	function _delDir($path)
	{
		return files::deltree($path);
	}
	
	
	
	/* Installation d'un lment */
	function importModule($url)
	{
		$dest = PT_MODULES_PATH.'/'.basename($url);
		
		$modules_path = path::real(PT_MODULES_PATH);
		$puntal_theme_path = path::real(PT_THEMES_PATH.'puntal/');
		$punbb_theme_path = path::real(PT_THEMES_PATH.'punbb/');
		
		if (($err = files::copyRemote($url,$dest)) !== true)
		{
			$this->err->setError($err);
			return false;
		}
		else {
			if (($content = @implode('',@gzfile($dest))) === false)
			{
				$this->err->setError(__('Cannot open file'));
				return false;
			}
			else {
				if (($list = unserialize($content)) === false)
				{
					$this->err->setError(__('Module not valid'));
					return false;
				}
				else {
					if (is_dir($modules_path.'/'.$list['name']))
					{
						unlink($dest);
						$this->err->setError(sprintf(__('This module still exists in %s. Delete it before.'),$modules_path));
						return false;
					}
					elseif (is_dir($puntal_theme_path.'/'.$list['name']))
					{
						unlink($dest);
						$this->err->setError(sprintf(__('This module still exists in %s. Delete it before.'),$puntal_theme_path));
						return false;
					}
					elseif (is_dir($punbb_theme_path.'/'.$list['name']))
					{
						unlink($dest);
						$this->err->setError(sprintf(__('This module still exists in %s. Delete it before.'),$punbb_theme_path));
						return false;
					}
					
					# dirs
					foreach ($list['dirs'] as $d)
					{
						$module_line = '';
						$theme_line = '';
						
                        # module directory 
						if (strpos($d,'/modules/') !== false)
						{
							$module_line = str_replace('/modules/', '', $d);
							if (!file_exists($modules_path.'/'.$module_line))
								$this->makeDir($modules_path.'/'.$module_line);
                        }
                        # puntal themes directory
						elseif (strpos($d,'/themes/puntal/') !== false)
						{
							$theme_line = str_replace('/themes/puntal/', '', $d);
							if (!file_exists($puntal_theme_path.'/'.$theme_line))
								$this->makeDir($puntal_theme_path.'/'.$theme_line);
                        }
                        # punbb themes directory
						elseif (strpos($d,'/themes/punbb/') !== false)
						{
							$theme_line = str_replace('/themes/punbb/', '', $d);
							if (!file_exists($punbb_theme_path.'/'.$theme_line))
								$this->makeDir($punbb_theme_path.'/'.$theme_line);
                        }
					}
					
					# files
					foreach ($list['files'] as $f=>$v)
					{
						$v = base64_decode($v);
						
						# module files
						if (strpos($f,'/modules/') !== false)
						{
							$module_line = str_replace('/modules/', '', $f);
							$this->makeFile($modules_path.'/'.$module_line,$v);
						}
                        # puntal themes directory
						elseif (strpos($f,'/themes/puntal/') !== false)
						{
							$theme_line = str_replace('/themes/puntal/', '', $f);
							$this->makeFile($puntal_theme_path.'/'.$theme_line,$v);
						}
                        # punbb themes directory
						elseif (strpos($f,'/themes/punbb/') !== false)
						{
							$theme_line = str_replace('/themes/punbb/', '', $f);
							$this->makeFile($punbb_theme_path.'/'.$theme_line,$v);
						}
					}
					
					unlink($dest);
				}
			}
		}
		return true;
	}	
}

?>