<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2005 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****

#
# Adapt  Puntal
#

function getExtension($f)
{
	$f = explode('.',basename($f));
	
	if (count($f) <= 1) return '';
	
	return strtolower($f[count($f)-1]);
}

function cleanPath($p)
{
	$p = str_replace('..','',$p);
	$p = preg_replace('|/{2,}|','/',$p);
	$p = preg_replace('|/$|','',$p);
	
	return $p;
}

function ourRealPath($p,$strict=true)
{
	$os = (DIRECTORY_SEPARATOR == '\\') ? 'win' : 'nix';
	
	# Absolute path?
	if ($os == 'win')
		$_abs = preg_match('/^\w+:/',$p);
	else
		$_abs = substr($p,0,1) == '/';
	
	# Standard path form
	if ($os == 'win') {
		$p = str_replace('\\','/',$p);
	}
	
	# Adding root if !$_abs 
	if (!$_abs)
		$p = dirname($_SERVER['SCRIPT_FILENAME']).'/'.$p;
	
	# Clean up
	$p = preg_replace('|/+|','/',$p);
	
	if (strlen($p) > 1)
		$p = preg_replace('|/$|','',$p);
	
	$_start = '';
	if ($os == 'win')
	{
		list($_start,$p) = explode(':',$p);
		$_start .= ':/';
	}
	else
		$_start = '/';
	
	$p = substr($p,1);
	
	# Go through
	$P = explode('/',$p);
	$res = array();
	
	for ($i=0;$i<count($P);$i++)
	{
		if ($P[$i] == '.')
			continue;
		
		if ($P[$i] == '..')
		{
			if (count($res) > 0)
				array_pop($res);
		}
		else
			array_push($res,$P[$i]);
	}
	
	$p = $_start.implode('/',$res);
	
	if ($strict && !@file_exists($p))
		return false;
	
	return $p;
}
	
$allow_types = array('png','jpg','jpeg','gif','css','js');
$mimes_types = array(
	'png'	=> 'image/png',
	'jpg'	=> 'image/jpeg',
	'jpeg'	=> 'image/jpeg',
	'gif'	=> 'image/gif',
	'css'	=> 'text/css',
	'js'	=> 'text/javascript',
);

require dirname(__FILE__).'/prepend.php';

if (empty($_GET['pf']))
	exit;

$pf = cleanPath($_GET['pf']);

foreach (array_reverse(explode(PATH_SEPARATOR,PT_MODULES_PATH)) as $m)
{
	$PF = ourRealPath($m.'/'.$pf);
	
	if ($PF !== false)
		break;
}

if ($PF === false || !is_file($PF) || !is_readable($PF))
	exit;

$ext = getExtension($PF);

if (!in_array($ext,$allow_types))
	exit;

header('Content-Type: '.$mimes_types[$ext]);
readfile($PF);
exit;
?>