<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

if (!defined('PUNTAL')) exit;

/**
	
	@brief ArticlesManager module class
	
	<strong>FR</strong> La classe de recuperation des articles et des categories d'articles<br/>	
	<strong>EN</strong> The class of management of the articles and categories of article
*/
class articlesManager
{
	var $pt;
	var $tp;
	var $tc;
	
	/**
	articlesManager<br/>
	
	<strong>FR</strong> Constructeur<br/>
	<strong>EN</strong> Constructor
	
	@param puntal <strong>object</strong> puntal type object
	*/
	function articlesManager(&$puntal)
	{
		$this->pt =& $puntal;
		$this->tp = DB_PREFIX.'pt_articles';
		$this->tc = DB_PREFIX.'pt_articles_cat';
		$this->tv = DB_PREFIX.'pt_articles_vote';
	}
	
	/**
	checkCat<br/>
	
	<strong>FR</strong> Verifie l'existence de la categorie. Retourne true ou false<br/>
	<strong>EN</strong> Check if the category exists. Return True or False.
		
	@param	cat_id <strong>integer</strong>		Category ID	
	@return	boolean
	*/
	function checkCat($cat_id)
	{
		$strReq = 
		'SELECT count(cat_id) FROM '.$this->tc.' '.
		'WHERE cat_id='.(integer) $cat_id.' ';
		
		$rs = $this->pt->con->select($strReq) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		if ($rs == false || $rs->field(0) == '0')
			return false;
		else
			return true;
	}
	
	/**
	getCat<br/>

	
	<strong>FR</strong> Selectionne une ou plusieurs categories.<br/>
	La parametre <strong>cat_id</strong> peut tre un entier ou une chaine.<br/>
	S'il s'agit d'un entier, la comparaison sera fait sur la colonne <strong>cat_id</strong>.<br/>
	S'il s'agit d'une chaine, la comparaison sera faite sur la colonne <strong>cat_url</strong>.<br/>
	
	Si le parametre <strong>cat_id</strong> est <em>vide</em>, toutes les categories seront
	renvoyees dans le recordset (fonctionnement par defaut).<br/>
	
	La methode renvoie <strong>false</strong> en cas d'erreur.<br/>

	<strong>EN</strong>Select one or more categories.<br/> 
	The parameter <strong>cat_id</strong> can be an integer or a string.
	If it's an integer, then it will be compare with the column <strong>cat_id</strong>. <br/>
	If it's a string, then it will be compare with the column <strong>cat_url</strong>.<br/>
	
	If the parameter <strong>cat_id</strong> is <em>empty</em>, 
	all the categories will be returned in the recordset (by default).<br/>
	
	the function return <strong>false</strong> in case of error.<br/>
		
	@param	cat_id	<strong>mixed</strong>	Category ID
	@param	order_by <strong>string</strong>	Field use to sort the results.
	@return	rs <strong>object</strong>	recordset
	*/
	function getCat($cat_id='',$order_by='cat_ord')
	{
		$reqPlus = '';
		
		if ($cat_id != '')
		{
			if (preg_match('/^[0-9]+$/',$cat_id))
				$reqPlus .= 'AND C.cat_id='.(integer) $cat_id.' ';
			else
				$reqPlus .= 'AND C.cat_url=\''.$this->pt->con->escapeStr($cat_id).'\' ';
		}
		
		$strReq = 
		'SELECT C.cat_id, cat_name, cat_url, cat_desc, '.
		'cat_ord, count(P.id) AS nb_articles '.
		'FROM '.$this->tc.' C '.
		'LEFT JOIN '.$this->tp.' P ON C.cat_id = P.cat_id '.
		'WHERE 1 '.
		$reqPlus.
		'GROUP BY C.cat_id '.
		'ORDER BY '.$this->pt->con->escapeStr($order_by);
		
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());

		return $rs;
	}
		
	/**
	getArticles<br/>
	
	<strong>FR</strong> Recuperation d'un ou de plusieurs article.<br/>
	<strong>EN</strong> Get one or more articles<br/>
	
	@param	id <strong>integer</strong>			Article ID 
	@param	cat_id <strong>integer</strong>		Category ID
	@param	status <strong>integer</strong>		Article(s) Status
	@param	order_by <strong>string</strong>	Sort the articles <em>P.date DESC</em>
	@param	limit <strong>string</strong>		Number of articles to return
	@return	recordset <strong>object</strong> 	Recordset
	*/
	function getArticles($id='',$cat_id='',$status='',$order_by='P.date DESC',$limit='')
	{
		$req_plus = ' 1';
		
		if ($id != '')
			$req_plus .= ' AND P.id='.(integer) $id.' ';
		
		if ($cat_id != '')
		{
			if (preg_match('/^[0-9]+$/',$cat_id))
				$req_plus .= ' AND C.cat_id='.(integer) $cat_id.' ';
			else
				$req_plus .= ' AND C.cat_url=\''.$this->pt->con->escapeStr($cat_id).'\' ';
		}
		
		if ($status != '')
			$req_plus .= ' AND P.status='.(integer) $status;
		
		$sql = 
		'SELECT P.id, P.title, P.url, P.content, P.date, P.cat_id, P.status, P.tid, P.pid, '.
		'C.cat_name, C.cat_url, '.
		'T.num_replies '.
		'FROM '.$this->tp.' P '.
		'LEFT JOIN '.$this->tc.' C ON P.cat_id = C.cat_id '.
		'LEFT JOIN '.DB_PREFIX.'topics T ON P.tid=T.id '.
		'WHERE '.$req_plus.' '.
		'ORDER BY '.$order_by;
				
		if ($limit != '')
			$sql = $sql.' LIMIT '.$limit;
		
		$rs = $this->pt->con->select($sql) or $this->pt->err->fatalError($this->pt->con->error());
		
		return $rs;
	}

	
	/**
	searchEntry<br/>
	
	<strong>FR</strong> recherche d'un article selon des mots cle et renvoie un recordset.
	<strong>EN</strong> search of an article by a given keyword and return the recordset
	
	@param	w	<strong>string</strong>		Keywords
    @param	limit <strong>string</strong>	Number of articles to return    
	@return	recordset <strong>object</strong> Recordset
	*/
	function searchEntry($w,$limit='')
	{
		$strip = array('+',')','(',',','\'');
		$w = strtolower($w);
		$w = str_replace($strip,' ',$w);
		$w = preg_replace('/( )+/',' ',$w);
		
		$reqPlus = '';
		foreach(explode(' ',$w) as $v)
		{
			$reqPlus .= 
			'AND (LOWER(P.title) LIKE \'%'.$this->pt->con->escapeStr($v).'%\' OR '.
			'LOWER(P.content) LIKE \'%'.$this->pt->con->escapeStr($v).'%\') ';
		}
		
		$sql = 
		'SELECT P.id, P.title, P.url, P.content, P.date, P.cat_id, P.status, P.tid, P.pid, '.
		'C.cat_name, C.cat_url, '.
		'T.num_replies '.
		'FROM '.$this->tp.' P '.
		'LEFT JOIN '.$this->tc.' C ON P.cat_id = C.cat_id '.
		'LEFT JOIN '.DB_PREFIX.'topics T ON P.tid=T.id '.
		'WHERE P.status=2 '.
		$reqPlus.
		'ORDER BY P.date DESC';
        
        if ($limit != '')
			$sql = $sql.' LIMIT '.$limit;     
            
		$rs = $this->pt->con->select($sql) or $this->pt->err->fatalError($this->pt->con->error());
		
		return $rs;
	}
		
	/**
	setArticle<br/>
	
	<strong>FR</strong> Ajout / modification d'un article. Renvoie l'id de l'article en cas de succes.<br/>
	<strong>EN</strong> Add / Modify an article. Return the article ID in case of success<br/>
	
	@param	name <strong>string</strong>			Article Title
	@param	cat <strong>integer</strong>			Article Category
	@param	content <strong>string</strong>			Article Content
	@param	date <strong>string</strong>			Article Date
	@param	status <strong>string</strong>			Status article
	@param	url <strong>string</strong>				Article title "URLized"
	@param	id <strong>integer</strong>				Article ID
	@param	tid <strong>integer</strong>			Topic ID of this article
	@param	<pid strong>integer</strong>			Post ID of this article
	@return	id <strong>integer</strong> 			the id inserted/updated
	*/
	function setArticle($title,$cat,$content,$date,$status=2,$url='',$id='',$tid=0,$pid=0)
	{
		$title 		= trim($title);
		$cat 		= intval($cat);
		$content 	= trim($content);
		$date 		= trim($date);
		$status 	= intval($status);
		$url 		= trim($url);
		
		if ($title == '')
			$this->pt->err->setError(__('You must give a title for the article.'));
		
		if ($content == '')
			$this->pt->err->setError(__('You must give a content for the article.'));
		
		if ($cat == '' || !$this->checkCat($cat))
			$this->pt->err->setError(__('Category not exists'));
		
		$url = ($url == '') ? $title : $url;
		$url = $this->pt->str2url($url);
		
		if ($url == '')
			$this->pt->err->setError(__('Empty or invalid article URL title'));
		
		if ($date == '')
			$puntal->err->setError(__('You must give a date for the article.'));
		else
			$date = date('Y-m-d H:i:s',strtotime($date));

		if ($this->pt->err->hasError())
			return false;
		
		$title = $this->pt->secureString($title);
		
		# Ajout d'un article
		if ($id == '')
		{			
			$insReq = 
			'INSERT INTO '.$this->tp.' '.
			'(title,url,content,date,cat_id,status,tid,pid) VALUES ('.
			'\''.$this->pt->con->escapeStr($title).'\', '.
			'\''.$this->pt->con->escapeStr($url).'\', '.
			'\''.$this->pt->con->escapeStr($content).'\', '.
			'\''.$this->pt->con->escapeStr($date).'\', '.
			(integer) $cat.', '.
			(integer) $status.', '.
			(integer) $tid.', '.
			(integer) $pid.' '.
			') ';
			
			$this->pt->con->execute($insReq) or $this->pt->err->fatalError($this->pt->con->error());

			$id = $this->pt->con->getLastID();
			return $id;
		}
		# Modification d'un article
		else {
			$updReq = 
			'UPDATE '	.$this->tp.' SET '.
			'title=\''	.$this->pt->con->escapeStr($title).'\', '.
			'url=\''	.$this->pt->con->escapeStr($url).'\', '.
			'content=\''.$this->pt->con->escapeStr($content).'\', '.
			'date=\''	.$this->pt->con->escapeStr($date).'\', '.
			'cat_id='	.(integer) $cat.', '.
			'status='	.(integer) $status.', '.
			'tid='		.(integer) $tid.', '.
			'pid='		.(integer) $pid.' '.
			'WHERE id='	.(integer) $id.' ';
			
			$this->pt->con->execute($updReq) or $this->pt->err->fatalError($this->pt->con->error());
			
			return $id;
		}
	}
	/**
	 setVote<br/>
	 <strong>FR</strong> Ajoute un vote a cet article<br/>
	 <strong>EN</strong> Add a vote to this article<br/>
	 
	 @param id_article <strong>integer</strong> article id to vote to
	 @param level <strong>integer</strong> estimated level given to this article
	 */
	function setVote($id_article,$level) {
		$minus = 0;
		$plus = 0;
		
		#un vote par utilisateur et par article
		if ($this->checkVote($id_article)) {
			$insReq = 
			'INSERT INTO '.$this->tv.' '.
				'(id_article,id_user,level) VALUES ('.
				(integer) $id_article.', '.
				(integer) $this->pt->user['id'].', '.
				(integer) $level.				
				') ';
				
			$this->pt->con->execute($insReq) or $this->pt->err->fatalError($this->pt->con->error());
			return __('Rate submitted');
		} 
		else return __('You already have rated this article');
	}

	/**
	 getVote<br/>
	 <strong>FR</strong> Recupere le vote d'un article<br/>
	 <strong>EN</strong> Get the vote of an article<br/>
	 
	 @param 	id_article <strong>integer</strong> article id
	 @return	recordset <strong>object</strong> 	Recordset 	 
	 */	
	function getVote($id_article) {
		$strReq = 
		'SELECT SUM(level) as ttl_level, count(id_article) as ttl FROM '.$this->tv.' '.
		'WHERE id_article='.(integer) $id_article.' GROUP BY id_article';

		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		return $rs;
	}

	/**
	 checkVote<br/>
	 <strong>FR</strong> Verifie que l'utilisateur courant n'a pas deja vote pour cet article<br/>
	 <strong>EN</strong> Check that the current user does not aleardy vote to this article<br/>
	 
	 @param 	id_article <strong>integer</strong> article id
	 @return	<strong>boolean</strong> 	 
	 */		
	function checkVote($id_article) {
		$strReq = 
			'SELECT id_article FROM '.$this->tv.' '.
			'WHERE id_article='.(integer) $id_article . ' AND id_user ='.$this->pt->user['id'];

		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		if ( $rs->nbRow() > 0 ) return false; else return true;

	}
}

?>