<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

if (!defined('PUNTAL')) exit;

/**
@function install_blog

La fonction charge de l'installation du module blog.
*/
function install_blog()
{
	/* Structure de la base de donnes
	----------------------------------------------------------*/
	$db_scheme = array();
	
	# Structure de la table 'pt_blog_categorie'
	$db_scheme[] = array(
		'action' 	=> 'add',
		'table' 	=> DB_PREFIX.'pt_blog_categorie',
		'query' 	=> 
		'CREATE TABLE '.DB_PREFIX.'pt_blog_categorie (
		cat_id 				INT(11) 		NOT NULL AUTO_INCREMENT,
		cat_libelle 		VARCHAR(255) 	NOT NULL DEFAULT \'\',
		cat_desc 			LONGTEXT,
		cat_libelle_url 	VARCHAR(255) 	NOT NULL DEFAULT \'\',
		cat_ord 			INT(11) 		DEFAULT NULL,
		PRIMARY KEY  (cat_id),
		UNIQUE KEY cat_libelle_url (cat_libelle_url),
		UNIQUE KEY cat_libelle (cat_libelle)
		) TYPE=MyISAM'
	);
	
	# Structure de la table 'pt_blog_post'
	$db_scheme[] = array(
		'action' 	=> 'add',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'CREATE TABLE '.DB_PREFIX.'pt_blog_post (
		post_id 			INT(11) 		NOT NULL AUTO_INCREMENT,
		user_id 			INT(11) 		NOT NULL DEFAULT 1,
		cat_id 				INT(11) 		DEFAULT NULL,
		post_dt 			DATETIME 		DEFAULT NULL,
		post_creadt 		DATETIME 		DEFAULT NULL,
		post_upddt 			DATETIME 		DEFAULT NULL,
		post_titre 			VARCHAR(255) 	DEFAULT NULL,
		post_titre_url 		VARCHAR(255) 	DEFAULT NULL,
		post_chapo 			LONGTEXT,
		post_content 		LONGTEXT,
		post_notes 			LONGTEXT,
		post_pub 			INT(1) 			NOT NULL DEFAULT 0,
		post_selected 		INT(1) 			NOT NULL DEFAULT 0,
		post_open_comment 	INT(1) 			NOT NULL DEFAULT 0,
		post_open_tb 		INT(1) 			NOT NULL DEFAULT 0,
		nb_comment 			INT(11) 		NOT NULL DEFAULT 0,
		nb_trackback 		INT(11) 		NOT NULL DEFAULT 0,
		post_lang 			VARCHAR(5) 		DEFAULT NULL,
		PRIMARY KEY  (post_id)
		) TYPE=MyISAM'
	);
	
	# Structure de la table 'pt_blog_comment'
	$db_scheme[] = array(
		'action' 	=> 'add',
		'table' 	=> DB_PREFIX.'pt_blog_comment',
		'query' 	=> 
		'CREATE TABLE '.DB_PREFIX.'pt_blog_comment (
		comment_id 			INT(11) 		NOT NULL AUTO_INCREMENT,
		post_id 			INT(11) 		NOT NULL DEFAULT 0,
		comment_dt 			DATETIME 		DEFAULT NULL,
		comment_upddt 		DATETIME 		DEFAULT NULL,
		comment_auteur 		VARCHAR(255) 	DEFAULT NULL,
		comment_email 		VARCHAR(255) 	DEFAULT NULL,
		comment_site 		VARCHAR(255) 	DEFAULT NULL,
		comment_content 	LONGTEXT,
		comment_ip 			VARCHAR(15) 	DEFAULT NULL,
		comment_pub 		INT(1) 			DEFAULT 0,
		comment_trackback 	INT(1) 			NOT NULL DEFAULT 0,
		PRIMARY KEY  (comment_id)
		) TYPE=MyISAM'
	);
	
	# FULLTEXT
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_post 
		ADD FULLTEXT full_post_titre (post_titre)'
	);
	
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_post 
		ADD FULLTEXT full_post_content (post_content)'
	);
	
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_post
		ADD FULLTEXT full_post_chapo (post_chapo)'
	);
	
	# INDEXES
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_post 
		ADD INDEX fk_post_categorie (cat_id,post_pub)'
	);
	
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_post',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_post 
		ADD INDEX fk_post_user (user_id,post_pub)'
	);
	
	$db_scheme[] = array(
		'action' 	=> 'update',
		'table' 	=> DB_PREFIX.'pt_blog_comment',
		'query' 	=> 
		'ALTER TABLE '.DB_PREFIX.'pt_blog_comment 
		ADD INDEX fk_comment_post (post_id)'
	);
	
	
	/* Paramtres de configuration
	----------------------------------------------------------*/
	$params = array();
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_nb_post_per_page',
		'type' 		=> 'integer',
		'init'		=> 10
	);
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_allow_comments',
		'type' 		=> 'boolean',
		'init'		=> true
	);
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_allow_trackbacks',
		'type' 		=> 'boolean',
		'init'		=> true
	);
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_comments_pub',
		'type' 		=> 'boolean',
		'init'		=> true
	);
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_comments_ttl',
		'type' 		=> 'integer',
		'init'		=> 0
	);
	
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_mod_blog_short_feeds',
		'type' 		=> 'integer',
		'init'		=> 0
	);
	$params[] = array(
		'action'	=> 'add',
		'name' 		=> 'pt_blog_use_smilies',
		'type' 		=> 'integer',
		'init'		=> 0
	);	


	/* Installation du module
	----------------------------------------------------------*/
	$GLOBALS['install_module']->install($db_scheme,$params);
}

?>