<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

if (!defined('PUNTAL')) exit;

/**
	
	@brief calendarAdminManager module class
	
	<strong>FR</strong> La classe d'administration des calendrier et des categories de calendrier<br/>	
	<strong>EN</strong> The class of administration  of the calendar and categories of calendar
*/


class calendarAdminManager extends calendarManager
{
	/* Categories
	----------------------------------------------------------*/
		
	/**
	setCat<br/>
	
	<strong>FR</strong> Ajout / modification d'une catgorie. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Add / modifiy the category. Return true in case of success.
	
	@param	cat_name <strong>string</strong>			Label of the category
	@param	cat_url <strong>string</strong>				label "URLized" of the category
	@param	cat_desc <strong>string</strong>			Description of the  category
	@param	cat_id <strong>integer</strong>				ID category.
	@return	<strong>boolean</strong>
	*/
	function setCat($cat_name,$cat_url='',$cat_desc='',$cat_id='')
	{
		$cat_name = trim($cat_name);
		$cat_url = trim($cat_url);
		
		if ($cat_name == '')
			$this->pt->err->setError(__('Empty category title'));
		
		$cat_url = ($cat_url == '') ? $cat_name : $cat_url;
		$cat_url = $this->pt->str2url($cat_url);
		
		$cat_url = ucfirst(preg_replace('/^[0-9]{4,}/','',$cat_url));
		
		if ($cat_url == '')
			$this->pt->err->setError(__('Empty or invalid category URL title'));
		
		$cat_name = $this->pt->secureString($cat_name);
		
		if ($this->pt->err->hasError())
			return false;
		
		# FR - Ajout d'une catgorie
		# EN - Add a category
		if ($cat_id == '')
		{
			$strReq = 'SELECT MAX(cat_ord) FROM '.$this->cc;
			
			$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());

			$max_ord = $rs->f(0);
			
			$insReq = 
			'INSERT INTO '.$this->cc.' '.
			'(cat_name,cat_url,cat_desc,cat_ord) VALUES ('.
			'\''.$this->pt->con->escapeStr($cat_name).'\','.
			'\''.$this->pt->con->escapeStr($cat_url).'\', '.
			'\''.$this->pt->con->escapeStr($cat_desc).'\', '.
			($max_ord+1).
			') ';
			
			$this->pt->con->execute($insReq) or $this->pt->err->setError($this->pt->con->error());

			logIt('calendar module : create category '.$cat_name, 1);
			return true;
		}
		
		# FR - Modification d'une catgorie
		# EN - Modifiy a category
		else {
			if (!$this->checkCat($cat_id))
			{
				$this->pt->err->setError(__('Category not exists'));
				return false;
			}
			
			$updReq = 
			'UPDATE '		.$this->cc.' SET '.
			'cat_name=\''	.$this->pt->con->escapeStr($cat_name).'\','.
			'cat_url=\''	.$this->pt->con->escapeStr($cat_url).'\', '.
			'cat_desc=\''	.$this->pt->con->escapeStr($cat_desc).'\' '.
			'WHERE cat_id='.(integer) $cat_id.' ';
			
			$this->pt->con->execute($updReq) or $this->pt->err->fatalError($this->pt->con->error());
			
			logIt('calendar module : update category '.$cat_name, 1);
			return true;
		}
	}
	
	/**
	delCat<br/>
	
	<strong>FR</strong> Suppression d'une catgorie donne. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Deletion of a given category. Return true in case of success
	
	@param	cat_id <strong>integer</strong>			ID of the category
	@return	<strong>boolean</strong>
	*/
	function delCat($cat_id)
	{
		if ($cat_id == '' || !$this->checkCat($cat_id))
			$this->pt->err->setError(__('Category not exists'));
		
		$rs = $this->getCat($cat_id);
		
		if ($rs->f('nb_calendar') > 0)
			$this->pt->err->setError(__('Category not empty'));
		
		if ($this->pt->err->hasError())
			return false;
		
		$cat_name = $rs->f('cat_name');
		
		$delReq = 
		'DELETE FROM '.$this->cc.' '.
		'WHERE cat_id='.(integer) $cat_id.' ';
		
		$this->pt->con->execute($delReq) or $this->pt->err->fatalError($this->pt->con->error());

		logIt('calendar module : delete category '.$cat_name, 3);
		$this->reordCats();
		return true;
	}
	
	/**
	@function reordCats<br/>
	
	<strong>FR</strong> Rordonner les catgories. Cette mthode va remettre les catgorie dans
	l'ordre (selon les ID ou selon les noms si byname est vrai).<br/>	
	Si check_url est vrai, les titres "URLiss" seront normaliss.<br/>
	
	<strong>EN</strong> Reorder the categories. This method is going to put the categories in order (in regards of the ID or the name if byname is true)<br/>
	If check_url is true, the  "URLized" titles will be Standardized.<br/>
		
	@param	check_url <strong>boolean</strong>			Standardized the URLized of the title
	@param	byname <strong>boolean</strong>			Sort by name
	*/
	function reordCats($check_url=false,$byname=false)
	{
		$ordby = $byname ? 'cat_name' : 'cat_ord';
		
		$i = 0;
		$strReq = 
		'SELECT cat_id, cat_url '.
		'FROM '.$this->cc.' '.
		'ORDER BY '.$ordby.' ';
		
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		
		while (!$rs->EOF())
		{
			$reqPlus = '';
			if ($check_url && preg_match('/^[a-z]/',$rs->f('cat_url')))
				$reqPlus = ', cat_url=\''.ucfirst($rs->f('cat_url')).'\' ';
			
			$updReq = 
			'UPDATE '.$this->cc.' SET '.
			'cat_ord='.(integer) $i.' '.
			$reqPlus.
			'WHERE cat_id='.(integer) $rs->f('cat_id').' ';
			
			$this->pt->con->execute($updReq) or $this->pt->err->fatalError($this->pt->con->error());
			
			$i++;
			$rs->moveNext();
		}
		logIt('calendar module : reord categories ', 1);
		return true;
	}
	
	/**
	ordCats<br/>
	
	<strong>FR</strong> Ordonne les catgories en utilisant les valeurs du tableau $ord. La cl est
	l'identifiant de la catgorie et la valeur, l'ordre de celle-ci.<br/>
	
	La mthode renvoie vrai en cas de succs.<br/>

	<strong>EN</strong> Sort the categories by using the value of the <strong>ord</strong> array. The key is the id of the category and the value , the order of this one<br/>
	
	the method retrun true in case of success<br/>
		
	
	@param	ord <strong>array</strong>	Array containing the order of each category
	@return	<strong>boolean</strong>
	*/
	function ordCats($ord)
	{
		if (!is_array($ord))
		{
			$this->pt->err->setError('Bad argument');
			return false;
		}
		
		foreach ($ord as $k => $v)
		{
			$updReq = 
			'UPDATE '.$this->cc.' SET '.
			'cat_ord='.(integer) $k.' '.
			'WHERE cat_id='.(integer) $v;
			
			$this->pt->con->execute($updReq) or $this->pt->err->fatalError($this->pt->con->error());
		}
		logIt('calendar module : sort categories ', 1);
		return true;
	}
	
}

?>