<?php


if (pt_mod_directory_google_pr)
	require dirname(__FILE__).'/googlepr.class.php';


/**

	@brief dirManager module class

*/
class dirManager
{
	var $puntal;
	var $t_cat;
	var $t_liens;
	var $gpr;
	

	/**
	dirManager<br/>
	
	<strong>FR</strong> Constructeur<br/>
	<strong>EN</strong> Constructor
	
	@param puntal <strong>object</strong> puntal type object
	*/		
	function dirManager(&$puntal)
	{
		$this->puntal = $puntal;

		$this->t_cat = DB_PREFIX.'pt_dir_categorie';
		$this->t_liens = DB_PREFIX.'pt_dir_entrie';
		
		if (pt_mod_directory_google_pr)
		{
			if (pt_mod_directory_google_pr_method)
				$this->gpr = new XGooglePR();
			else
				$this->gpr = new GooglePR();
			
			$this->gpr->userAgent = $_SERVER["HTTP_USER_AGENT"];
			$this->gpr->cacheDir = PT_CACHE_PATH.'directory_google_pr';
			$this->gpr->maxCacheAge = (3600*pt_mod_directory_google_pr_ttl);
			$this->gpr->useCache = true;
			$this->gpr->debug = false;
		}
		
		return true;
	}	
	
	/**
	getTotalCat<br/>
		
	<strong>FR</strong> Retourne le nombre total de rubriques<br/>
	<strong>EN</strong> Return the total number of categories	
	 */
	function getTotalCat()
	{
		$sql = 
		'SELECT COUNT(cat_id) AS num_cat '.
		'FROM '.$this->t_cat;
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return $rs->f('num_cat');
	}	
	

	/**
	getTotalLiens<br/>
		
	<strong>FR</strong> Retourne le nombre total de liens actifs<br/>
	<strong>EN</strong> Return the total number of active links	
	 */	 
	function getTotalLiens()
	{
		$sql = 
		'SELECT COUNT(entry_id) AS num_link '.
		'FROM '.$this->t_liens.' '.
		'WHERE entry_state=3';
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return $rs->f('num_link');
	}	
	
	/**
	getValidateLiens<br/>
		
	<strong>FR</strong> Retourne le nombre de liens  valider<br/>
	<strong>EN</strong> Return the total number of links to validate	
	 */	 
	function getValidateLiens()
	{
		$sql = 
		'SELECT COUNT(entry_id) AS num_link '.
		'FROM '.$this->t_liens.' '.
		'WHERE entry_state=0';
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return $rs->f('num_link');
	}
	
	
	/* ===================================================
	Rubriques
	=================================================== */
	
	/**
	checkCat<br/>
		
	<strong>FR</strong> Vrifie l'existence d'une rubrique. Renvoie vrai ou faux.<br/>
	<strong>EN</strong> Check that a category exists, return true or false
	
	@param	cat_id<strong>integer</strong>	 Category ID
	
	@return	<strong>boolean</strong>		
	 */	
	function checkCat($cat_id)
	{
		$sql = 
		'SELECT count(cat_id) FROM '.$this->t_cat.' '.
		'WHERE cat_id='.(integer) $this->puntal->con->escapeStr($cat_id).' ';
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		if ($rs == false || $rs->field(0) == '0')
			return false;
		else
			return true;
	}
	

	/**
	getCat<br/>

	<strong>FR</strong> Selectionne une ou plusieurs categories.<br/>
	La parametre <strong>cat_id</strong> peut tre un entier ou une chaine.<br/>
	S'il s'agit d'un entier, la comparaison sera fait sur la colonne <strong>cat_id</strong>.<br/>
	S'il s'agit d'une chaine, la comparaison sera faite sur la colonne <strong>cat_url</strong>.<br/>
	
	Si le parametre <strong>cat_id</strong> est <em>vide</em>, toutes les categories seront
	renvoyees dans le recordset (fonctionnement par defaut).<br/>
	
	La methode renvoie <strong>false</strong> en cas d'erreur.<br/>

	<strong>EN</strong>Select one or more categories.<br/> 
	The parameter <strong>cat_id</strong> can be an integer or a string.
	If it's an integer, then it will be compare with the column <strong>cat_id</strong>. <br/>
	If it's a string, then it will be compare with the column <strong>cat_url</strong>.<br/>
	
	If the parameter <strong>cat_id</strong> is <em>empty</em>, 
	all the categories will be returned in the recordset (by default).<br/>
	
	the function return <strong>false</strong> in case of error.<br/>
	
	@param	cat_id	<strong>mixed</strong>	Category ID
	@param	order_by <strong>string</strong>	Field use to sort the results.
	@param	root <strong>string</strong>		Parent Category
	@return	rs <strong>object</strong>	recordset	
	*/
	function getCat($cat_id='',$order_by='cat_ord',$root=false,$statut=NULL)
	{
		$reqPlus = "WHERE 1 ";
		
		if (is_integer($statut) && ($statut == 0 || $statut == 1 || $statut == 2 || $statut ==3))
			$reqPlus .= 'AND L.entry_state='.(integer) $statut.' ';
		
		if ($root !== false)
			$reqPlus .= 'AND cat_root=\''.$this->puntal->con->escapeStr($root).'\' ';
		
		if ($cat_id != '')
		{
			if (preg_match('/^[0-9]+$/',$cat_id))
				$reqPlus .= 'AND C.cat_id='.(integer) $cat_id.' ';
			else
				$reqPlus .= 'AND C.cat_name_url=\''.$this->puntal->con->escapeStr($cat_id).'\' ';
		}
		
		$sql = 
		'SELECT C.cat_id, cat_name, cat_name_url, cat_desc, '.
		'cat_root, cat_ord, count(L.entry_id) AS nb_lien '.
		'FROM '.$this->t_cat.' C '.
			'LEFT JOIN '.$this->t_liens.' L ON C.cat_id=L.entry_category '.
		$reqPlus.
		'GROUP BY C.cat_id '.
		'ORDER BY '.$this->puntal->con->escapeStr($order_by);

		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return $rs;
	}
	
	
	/**
	getListCat<br/>
	
	<strong>FR</strong> Renvoit la liste de toutes les rubriques.<br/>
	<strong>EN</strong> Retrun the list of all the categories.
	
	@param	rsCat <strong>object</strong>			Recordest containing all categories
	@param	arryCat <strong>array</strong>			Array containing categories
	@param	cat_id <strong>string</strong>			Category ID of the beginning 
	@param	index <strong>string</strong>			ID of the beginning in the recordset
	@param	niveau <strong>string</strong>			Start Level
	*/
	function getListCat(&$rsCat, &$arryCat, $cat_name_url, $index, $niveau='0', $indent_text='&nbsp;&nbsp;')
	{
		$rsCat->moveStart();
		
		$indent = '';
		
		for ($i=0; $i<$niveau; $i++)
			$indent .= $indent_text;
			
		while (!$rsCat->EOF())
		{
			if ($rsCat->field('cat_root') == $cat_name_url)
			{
				$arryCat[$indent.html::escapeHTML($rsCat->field('cat_name'))] = $rsCat->field('cat_id');
				$this->getListCat($rsCat,$arryCat,$rsCat->field('cat_name_url'),$rsCat->int_index,$niveau+1,$indent_text);
			}
			$rsCat->moveNext();
		}	
		$rsCat->move($index);
	}
	
	
	/**
	setCat<br/>
	
	<strong>FR</strong> Ajout/modification d'une rubrique. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Add / Modify a category. Return true in case of success
	
	@param	titre <strong>string</strong>		category title
	@param	root <strong>string</strong>		URLized of the parent category
	@param	titre_url <strong>string</strong>	URLized of the category title
	@param	desc <strong>string</strong>		Category Description
	@param	cat_id	<strong>integer</strong>	Category ID to modify the category
	@return	<strong>boolean</strong>
	*/
	function setCat($titre,$root='',$titre_url='',$desc='',$cat_id='')
	{
		$titre = trim($titre);
		$titre_url = trim($titre_url);
		$desc = trim($desc);
		
		if ($titre == '')
		{
			$this->puntal->err->setError(__('Empty category title'));
			return false;
		}
		
		$titre_url = ($titre_url == '') ? $titre : $titre_url;
		$titre_url = $this->puntal->str2url($titre_url);
		
		# Ajout des protections sur le libelle_url
		$titre_url = ucfirst(preg_replace('/^[0-9]{4,}/','',$titre_url));
		
		if ($titre_url == '')
		{
			$this->puntal->err->setError(__('Empty or invalid category URL title'));
			return false;
		}
		
		$titre = $this->puntal->secureString($titre);
				
		
		# Ajout d'une catgorie
		if ($cat_id == '')
		{
			$sql = 'SELECT MAX(cat_ord) FROM '.$this->t_cat;
			$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
			$max_ord = $rs->f(0);
			
			$sql = 
			'INSERT INTO '.$this->t_cat.' '.
			'(cat_name, cat_name_url, cat_desc, cat_root, cat_ord) VALUES ( '.
			'\'' . $this->puntal->con->escapeStr($titre) . '\', ' .
			'\'' . $this->puntal->con->escapeStr($titre_url) . '\', ' .
			'\'' . $this->puntal->con->escapeStr($desc) . '\', ' .
			'\'' . $this->puntal->con->escapeStr($root) . '\', ' .
			(integer)($max_ord+1).
			' ) ';
			
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
			
			logIt('Directory module : create category '.$titre, 1);
			return true;
		}
		else {
			if (!$this->checkCat($cat_id))
			{
				$this->puntal->err->setError('Rubrique inexistante');
				return false;
			}
			
			$sql = 
			'UPDATE '.$this->t_cat.' SET '.
			'cat_name=\''.$this->puntal->con->escapeStr($titre).'\', '.
			'cat_name_url=\''.$this->puntal->con->escapeStr($titre_url).'\', '.
			'cat_desc=\''.$this->puntal->con->escapeStr($desc).'\' '.
			'WHERE cat_id='.(integer) $cat_id.' ';
			
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
			
			logIt('Directory module : update category '.$titre, 1);
			return true;
		}
	}

	/**
	delCat<br/>
	
	<strong>FR</strong> Suppression d'une rubrique donne. Renvoie vrai en cas de succs..<br/>
	<strong>EN</strong> Remove a category. Return true in case of success
	
	@param	cat_id	<strong>integer</strong>	Category ID to be removed
	@return	<strong>boolean</strong>
	*/	
	function delCat($cat_id)
	{				
		$rs = $this->getCat($cat_id);
		
		if ($rs->f('nb_post') > 0)
		{
			$this->puntal->err->setError('Cette rubrique n\'est pas vide');
			return false;
		}
		
		$sql = 
		'DELETE FROM '.$this->t_cat.' '.
		'WHERE cat_id='.(integer) $cat_id.' ';
			
		$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		$this->reordCats();
		logIt('Directory module : Delete category '.$rs->f('cat_name'), 3);
		return true;
	}
		
	
	/**
	@function reordCats<br/>
	
	<strong>FR</strong> Rordonner les catgories. Cette mthode va remettre les catgorie dans
	l'ordre (selon les ID ou selon les noms si byname est vrai).<br/>	
	Si check_url est vrai, les titres "URLiss" seront normaliss.<br/>
	
	<strong>EN</strong> Reorder the categories. This method is going to put the categories in order (in regards of the ID or the name if byname is true)<br/>
	If check_url is true, the  "URLized" titles will be Standardized.<br/>
		
	@param	check_url <strong>boolean</strong>			Standardized the URLized of the title
	@param	byname <strong>boolean</strong>			Sort by name
	*/	
	function reordCats($check_url=false,$byname=false)
	{
		$ordby = $byname ? 'cat_name' : 'cat_ord';
		
		$i = 0;
		$sql = 
		'SELECT cat_id, cat_name_url '.
		'FROM '.$this->t_cat.' '.
		'ORDER BY '.$ordby;
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
				
		while (!$rs->EOF())
		{
			$reqPlus = '';
			if ($check_url && preg_match('/^[a-z]/',$rs->f('cat_name_url')))
				$reqPlus = ',cat_name_url=\''.ucfirst($rs->f('cat_name_url')).'\' ';
			
			$sql = 
			'UPDATE '.$this->t_cat.' SET '.
			'cat_ord='.(integer) $i.' '.
			$reqPlus.
			'WHERE cat_id='.(integer) $rs->f('cat_id').' ';
			
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
			
			$i++;
			$rs->moveNext();
		}
		
		return true;
	}
	

	/**
	ordCats<br/>
	
	<strong>FR</strong> Ordonne les catgories en utilisant les valeurs du tableau $ord. La cl est
	l'identifiant de la catgorie et la valeur, l'ordre de celle-ci.<br/>
	
	La mthode renvoie vrai en cas de succs.<br/>

	<strong>EN</strong> Sort the categories by using the value of the <strong>ord</strong> array. The key is the id of the category and the value , the order of this one<br/>
	
	the method retrun true in case of success<br/>
		
	
	@param	ord <strong>array</strong>	Array containing the order of each category
	@return	<strong>boolean</strong>
	*/
	function ordCats($ord)
	{
		if (!is_array($ord))
		{
			$this->puntal->err->setError('Bad argument');
			return false;
		}
		
		foreach ($ord as $k => $v)
		{
			$sql =
			'UPDATE '.$this->t_cat.' SET '.
			'cat_ord='.(integer) $k.' '.
			'WHERE cat_id='.(integer) $v.' ';
			
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		}
		
		return true;
	}
	
	
	/* ===================================================
	Liens
	
	Statuts:
	0: site inscrit mais pas encore valid par l'administrateur
	1: lien mort
	2: site hors ligne
	3: site en ligne
	=================================================== */

	
	/**
	searchEntry<br/>
	
	<strong>FR</strong> recherche d'un site selon des mots cle et renvoie un recordset.
	<strong>EN</strong> search of a website by a given keyword and return the recordset
	
	@param	w	<strong>string</strong>		Keywords
    @param	limit <strong>string</strong>	Number of articles to return    
	@return	recordset <strong>object</strong> Recordset
	*/	
	function searchEntry($w,$limit='')
	{
		$strip = array('+',')','(',',','\'');
		$w = strtolower($w);
		$w = str_replace($strip,' ',$w);
		$w = preg_replace('/( )+/',' ',$w);
		
		$reqPlus = '';
		foreach(explode(' ',$w) as $v)
		{
			$reqPlus .= 
			'AND (LOWER(entry_name) LIKE \'%'.$this->puntal->con->escapeStr($v).'%\' OR '.
			'LOWER(entry_url) LIKE \'%'.$this->puntal->con->escapeStr($v).'%\' OR '.
			'LOWER(entry_description) LIKE \'%'.$this->puntal->con->escapeStr($v).'%\') ';
		}
		
		$sql = 
		'SELECT entry_id, entry_name, entry_url, entry_dt, '.
		'entry_lang, entry_description, entry_state, '.
		'entry_category, entry_pr '.
		'FROM '.$this->t_liens.' '.
		'WHERE entry_state=3 '.
		$reqPlus.
		'ORDER BY \'entry_name\' ';
        
        if ($limit != '')
			$sql = $sql.' LIMIT '.$limit;     		
            
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());

		return $rs;
	}


	/**
	getLink<br/>
	
	<strong>FR</strong> Slectionne un ou plusieurs liens.<br/>
	
	Si le champs id est vide alors tous les liens de la rubrique cat_id seront retourns. <br/>
	Si id et cat_id sont vides alors tous les liens seront retourns.<br/>
		
	La mthode renvoie false en cas d'erreur.<br/>
	
	<strong>EN</strong> Selectionne one or more links<br/>
	If the id is empty then the link of the category catd_id will be returned.<br/>
	If the id and cat_id are empty then all the links will be returned<br/>
	the function return false is case of error <br/>
	
	@param	id <strong>mixed</strong>					Link ID to return
	@param	cat_id <strong>mixed</strong>				category ID
	@param	state <strong>mixed</strong>				Link status
	@param	order_by <strong>string</strong>			field used to sort the results
	@param	order <strong>string</strong>				Sort order
	@param	limit <strong>string</strong>				Number of link to return
	@return	rs <strong>object</strong> 					recordset 
	*/
	function getLink($id='',$cat_id='',$state='',$order_by='entry_name',$order='ASC',$limit='',$selected='')
	{			
		$reqPlus = '';
		
		if ($state != '')
			$reqPlus .= 'WHERE entry_state='.(integer) $state.' ';
		else
			$reqPlus .= 'WHERE 1 ';
		
		if ($id != '')
			$reqPlus .= 'AND entry_id='.(integer) $id.' ';
		
		if ($cat_id != '')
			$reqPlus .= 'AND entry_category='.(integer) $cat_id.' ';
		
		if ($selected != '')
			$reqPlus .= 'AND entry_selected='.(integer) $selected.' ';
		
		if ($limit != '')
			$limit = ' LIMIT 0,'.$limit;
		
		$sql = 
		'SELECT entry_id, entry_name, entry_url, entry_dt, '.
		'entry_lang, entry_description, entry_state, '.
		'entry_category, entry_pr, entry_clik, entry_selected '.
		'FROM '.$this->t_liens.' '.
		$reqPlus.
		'ORDER BY '.$this->puntal->con->escapeStr($order_by).' '.$order.
		$limit;
		
		$rs = $this->puntal->con->select($sql) or $this->puntal->err->fatalError($this->puntal->con->error());

		return $rs;
	}
	
	
	/**
	setLink<br/>
	

	<strong>FR</strong> Ajout/modification d'un lien<br/>
	<strong>EN</strong> Add / Modify a link.
	
	@param	titre <strong>string</strong>		category title
	@param	url <strong>string</strong>			link url
	@param	state <strong>integer</strong>		Link status
	@param	cat_id	<strong>integer</strong>	Category ID to modify the category
	@param	desc <strong>string</strong>		Link Description
	@param	lang <strong>string</strong>		Language of the website of this link
	@param	selected <strong>integer</strong>		Selected Link or not ?
	
	@return	<strong>boolean</strong>
	*/	
	function setLink($titre,$url,$date,$state=0,$cat_id=0,$desc='',$lang='',$selected=0,$id='')
	{
		$titre = trim($titre);
		$url = trim($url);
		$lang = trim($lang);
		$date = trim($date);
		$desc = trim($desc);
		
		# si la liste deroulante des categories est vide : erreur et l'admin doit en crer une sur la page d'admin du module.
		if (! $cat_id > 0 )
			$this->puntal->err->setError(__('You must select a category'));
		
		if ($titre == '')
			$this->puntal->err->setError(__('Empty website name'));
		
		if ($url == '' || str_replace('http://', '', $url) == '')
			$this->puntal->err->setError(__('URL website name'));
		
		if ($date == '')
			$this->puntal->err->setError(__('You must give a date'));
		else
			$date = date('Y-m-d H:i:s',strtotime($date));
		
		if ($this->puntal->err->hasError())
			return false;
				
		if (pt_mod_directory_google_pr)
			$pr = $this->getPageRank($url);
		else
			$pr = '0';
		
		$titre = $this->puntal->secureString($titre);
		
		if ($id == '')
		{
			$sql = 
			'INSERT INTO '.$this->t_liens.' '. 
			'( entry_name, entry_url, entry_dt, entry_lang, entry_description, '.
			'entry_state, entry_category, entry_pr, entry_selected ) VALUES ('.
			'\''.$this->puntal->con->escapeStr($titre).'\', '.
			'\''.$this->puntal->con->escapeStr($url).'\', '.
			'\''.$this->puntal->con->escapeStr($date).'\', '.
			'\''.$this->puntal->con->escapeStr($lang).'\', '.
			'\''.$this->puntal->con->escapeStr($desc).'\', '.
			(integer) $state.', '.
			(integer) $cat_id.', '.
			(integer) $pr.', '.
			(integer) $selected.' '.
			') ';
					
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());

			$entry_id = $this->puntal->con->getLastID();
			
			if ($state>0)
				logIt('Directory module : add link '.$entry_id, 1);
			
			return $entry_id;
		}
		else {
			$sql = 
			'UPDATE '.$this->t_liens.' SET '.
			'entry_name=\''.$this->puntal->con->escapeStr($titre).'\','.
			'entry_url=\''.$this->puntal->con->escapeStr($url).'\', '.
			'entry_dt=\''.$this->puntal->con->escapeStr($date).'\', '.
			'entry_lang=\''.$this->puntal->con->escapeStr($lang).'\', '.
			'entry_description=\''.$this->puntal->con->escapeStr($desc).'\', '.
			'entry_state='.(integer) $state.', '.
			'entry_category='.(integer) $cat_id.', '.
			'entry_pr='.(integer) $pr.', '.
			'entry_selected='.(integer) $selected.' '.
			'WHERE entry_id='.(integer) $id.' ';
			
			$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
			logIt('Directory module : update link '.$id, 1);
			return true;
		}
	}	
	
	/**
	setLinkStatut<br/>
	

	<strong>FR</strong> Modification du statut d'un lien. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Modify the status of a link. Return true in case of success
	
	@param	id <strong>integer</strong>			Link ID
	@param	state <strong>integer</strong>		Link status
	
	@return	<strong>boolean</strong>
	*/	
	function setLinkStatut($id,$state)
	{
		$sql = 
		'UPDATE '.$this->t_liens.' SET '.
		'entry_state='.(integer) $state.' '.
		'WHERE entry_id='.(integer) $id.' ';
		
		$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return true;
	}
	
	
	/**
	setLinkPr<br/>
	
	<strong>FR</strong> Modification du PageRank d'un lien. Renvoie vrai en cas de succs.<br/>
	<strong>FR</strong> Modification of a pageRank Link. Return true in case of success
	
	@param	id <strong>integer</strong>			Link ID
	@param	pr <strong>integer</strong>			PageRank
	
	@return	<strong>boolean</strong>
	*/
	function setLinkPr($id,$pr)
	{
		$sql = 
		'UPDATE '.$this->t_liens.' SET '.
		'entry_pr='.(integer) $pr.' '.
		'WHERE entry_id='.(integer) $id.' ';
		
		$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return true;
	}
	
	
	/**
	addLinkClik<br/>
	
	<strong>FR</strong> Itration du compteur de clique d'un lien. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Click accounting. Return true in case of success
	
	@param	id <strong>integer</strong>			Link ID
	@return	<strong>boolean</strong>
	*/
	function addLinkClik($id)
	{
		$sql =
		'UPDATE '.$this->t_liens.' '.
		'SET entry_clik=entry_clik+1 '.
		'WHERE entry_id='.(integer) $id.' ';
		
		$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		return true;
	}
	
	
	/**
	delLink<br/>
	
	<strong>FR</strong> Suppression d'un lien donn. Renvoie vrai en cas de succs.<br/>
	<strong>EN</strong> Deletion of a given link.  Return true in case of success
	
	@param	id <strong>integer</strong>			Link ID
	@return	<strong>boolean</strong>
	*/
	function delLink($id)
	{
		$sql = 
		'DELETE FROM '.$this->t_liens.' '.
		'WHERE entry_id='.(integer) $id.' ';
		
		$this->puntal->con->execute($sql) or $this->puntal->err->fatalError($this->puntal->con->error());
		
		logIt('Directory module : delete link '.$id, 3);
		return true;
	}
	
	
	/**
	test_url<br/>
	
	<strong>FR</strong> Teste si une URL distante rpond.<br/>
	<strong>EN</strong> Test if an URL respond
	
	@param	url <strong>string</strong>			URL to test
	@return	<strong>boolean</strong>
	*/	
	function test_url($url)
	{
		@ini_set('allow_url_fopen', '1');
		if (@fclose(@fopen($url,'r')))
			return true;
		else
			return false;
	}

	/* ===================================================
	Google PageRank
	=================================================== */

	/**
	getPageRank<br/>
	
	<strong>FR</strong> PageRank calcul.<br/>
	<strong>EN</strong> PageRank calcul
	
	@param	url <strong>string</strong>			URL
	@return	<strong>boolean</strong>
	*/		
	function getPageRank($url)
	{
		return $this->gpr->GetPR($url);
	}

	/**
	updPr<br/>
	
	<strong>FR</strong> Mise  jour du PageRank.<br/>
	<strong>EN</strong> PageRank Update
	
	@param	url <strong>string</strong>			URL 

	*/		
	function updPr(&$liens)
	{
		if (pt_mod_directory_google_pr)
		{
			while ($liens->fetch())
			{
				$neo_pr = $this->gpr->GetPR($liens->f('entry_url'));
				
				if ($liens->f('entry_pr') != $neo_pr)
					$this->setLinkPr($liens->f('entry_id'),$neo_pr);
			}
		}
	}


}

?>