<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

/**
	@brief  dir template class
*/
class dir
{	

	function menu($block='<ul id="dir-menu">%s</ul>', $item='<li><a href="%s">%s</a></li>', $actif='<li class="active"><a href="%s">%s</a></li>')
	{
		global $puntal, $dir_mode;
		
		$rs = '';
		$rs .= sprintf(($dir_mode == 'home' ? $actif : $item), $puntal->url('directory'), __('Directory home'));
		$rs .= sprintf(($dir_mode == 'novelties' ? $actif : $item), $puntal->url('directory_novelties'), __('Novelties'));
		
		if (pt_mod_directory_tc)
			$rs .= sprintf(($dir_mode == 'topclick' ? $actif : $item), $puntal->url('directory_topclicks'), __('Top clicks'));
			
		if (pt_mod_directory_google_pr)
			$rs .= sprintf(($dir_mode == 'toprank' ? $actif : $item), $puntal->url('directory_toprank'), __('Top Google Page Rank'));
		
		if ($puntal->user['is_admin'] || in_array($puntal->user['g_id'], $GLOBALS['allowed_groups']))
			$rs .= sprintf(($dir_mode == 'submit' ? $actif : $item), $puntal->url('directory_submit'), __('Submit a website'));
		
		printf($block, $rs);
	}
	
	/**
	@function selection<br/>
	
	Cette fonction affiche une liste des sites slectionns.
	
	
	@param string  block Chaine de substitution pour pour la liste ('<div class="selected_links><h2>Sites  l\'honneur</h2>%s</div>')
	@param string  item  Chaine de substitution pour un lment ('<li><a href="%2$s">%1$s</a></li>')
	@param integer limit Nombre de sites  afficher (ilimit)
	@param integer tri	 Le type de tri des lments, peut tre 
							- 'nom' pour un tri par intitul
							- 'date' pour un tri par date 
							- 'clique' pour un tri par nombre de clique
							- 'random' pour un tri alatoire
														
	*/
	function selection(
				$block='<div class="selected_links"><h3>Site(s)  l\'honneur</h3>%s</div>',
				$empty_block='',
				$item='<h4 class="website">%s</h4>%s',
				$limit='',
				$tri='random')
	{
		switch ($tri)
		{
			case 'date':
				$order_by = 'entry_dt';
				break;
			case 'clique':
				$order_by = 'entry_clik';
				break;
			case 'random':
				$order_by = 'RAND()';
				break;
			default :
			case 'nom':
				$order_by = 'entry_name';
				break;
		}
		
		if ($GLOBALS['dir_mode'] == 'cat' && $GLOBALS['dir_cat_id'])
			$links = $GLOBALS['dir']->getLink('',$GLOBALS['cat']->f('cat_id'),'3',$order_by,'DESC',$limit,1);
		else
			$links = $GLOBALS['dir']->getLink('','','3',$order_by,'DESC',$limit,1);
		
		if (!$links->isEmpty())
		{
			
			$res = '';
			while ($links->fetch())
			{
				$link = 
					'<a href="'.DIR_URL_SHOW.'/'.$links->f('entry_id').'"'.
					(($links->f('entry_lang') != '') ? ' hreflang="'.$links->f('entry_lang').'"' : '' ).
					'>'.$links->f('entry_name').'</a>';
					
				$res .= sprintf($item,$link,parse_message($links->f('entry_description'),false));
			}
			printf($block,$res);
		}
		else 
			echo $empty_block;
	}
	
	/**
	@function nombreLiens
	
	Cette fonction affiche le nombre total de liens dans l'annuaire.
	*/
	function nombreLiens()
	{
		$nb = $GLOBALS['dir']->getTotalLiens();
		
		if ($nb == 0)
			echo __('There is no website');
			
		elseif ($nb == 1)
			echo __('There is one website');
			
		elseif ($nb > 1)
			printf(__('There is %s websites'),$nb);
	}
	
	/**
	@function nombreCategories
	
	Cette fonction affiche le nombre total de rubrique dans l'annuaire.
	*/
	function nombreCategories()
	{
		$nb = $GLOBALS['dir']->getTotalCat();
		
		if ($nb == 0)
			echo __('and no category.');
			
		elseif ($nb == 1)
			echo __('in one category.');
			
		elseif ($nb > 1)
			printf(__('in %s category.'),$nb);
	}
	
	/**
	@function curCatName
	
	Cette fonction affiche le nom de la rubrique actuellement affiche 
	dans le contexte de l'affichage d'une rubrique.
	*/
	function curCatName()
	{
		echo html::escapeHTML($GLOBALS['cat']->f('cat_name'));
	}
	
	/**
	@function curCatDesc
	
	Cette fonction affiche la description de la rubrique actuellement affiche 
	dans le contexte de l'affichage d'une rubrique.
	*/
	function curCatDesc()
	{
		$desc = parse_message($GLOBALS['cat']->f('cat_desc'),false);
		
		if (!empty($desc))
			echo $desc;
	}
	
	/**
	@function parentCat
	
	Cette fonction affiche un lien vers la catgorie parent de la catgorie 
	actuellement affiche dans le contexte de l'affichage d'une catgorie.
	
	@param string block 	Masque de formatage du block (<p>%s</p>)
	*/
	function parentCat($block='<p>&larr; %s</p>')
	{
		global $cat;
		
		if ($cat->f('cat_root') != '')
			printf($block, '<a href="'.sprintf($GLOBALS['puntal']->url('directory_cat'),$cat->f('cat_root')).'">'.__('Back to parent category').'</a>');
		else
			printf($block, '<a href="'.$GLOBALS['puntal']->url('directory').'">'.__('Back to parent category').'</a>');
	}
	
	/**
	@function catName
	
	Cette fonction affiche le nom d'une rubrique dans le contexte
	d'une liste de rubriques.
	*/
	function catName()
	{
		echo html::escapeHTML($GLOBALS['cats']->f('cat_name'));
	}
	
	/**
	@function catUrl
	
	Cette fonction affiche l'url d'une rubrique dans le contexte
	d'une liste de rubriques.
	*/
	function catUrl()
	{
		global $cats;
		
		printf($GLOBALS['puntal']->url('directory_cat'),$cats->f('cat_name_url'));
	}
	
	/**
	@function catNumLink
	
	Cette fonction affiche le liens d'adresses d'une rubrique dans le contexte
	d'une liste de rubriques.
	
	@param 	string 	format 		Masque de formatage de la chaine de caractre ((%s))
	*/
	function catNumLink($format='(%s)')
	{
		printf($format,$GLOBALS['cats']->f('nb_lien'));		
	}
	
	/**
	@function subCat
	
	Cette fonction affiche la liste des sous-rubriques d'une rubrique 
	dans le contexte d'une liste de rubriques.
	
	@param string block 	Masque de formatage du bloc contenant la liste (<ul class="subcats">%s</ul>)
	@param string item	 	Masque de formatage d'un lment de la liste(<li><a href="%s">%s</a> (%s)</li>)
	*/
	function subCat($block='<ul class="subcats">%s</ul>', $item='<li><a href="%s">%s</a>&nbsp;(%s)</li>')
	{
		global $dir, $cats;
		
		$items = '';
		
		$subcats = $dir->getCat('','cat_ord',$cats->f('cat_name_url'));
		while ($subcats->fetch())
			$items .= sprintf($item, sprintf($GLOBALS['puntal']->url('directory_cat'),$subcats->f('cat_name_url')), html::escapeHTML($subcats->f('cat_name')), $subcats->f('nb_lien'));
		
		if ($items != '')
			printf($block, $items);
	}
	
	/**
	@function linkUrl
	
	Cette fonction affiche l'url d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkUrl()
	{
		echo $GLOBALS['liens']->f('entry_url');
	}
	
	/**
	@function linkGo
	
	Cette fonction affiche l'url pour visiter un site dans le contexte 
	d'une liste de sites.
	*/
	function linkGo()
	{
		if (pt_mod_directory_tc)
			printf($GLOBALS['puntal']->url('directory_goto'),$GLOBALS['liens']->f('entry_id'));
		else
			echo $GLOBALS['liens']->f('entry_url');
	}
	
	/**
	@function linkHrefLang
	
	Cette fonction affiche la langue d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkHrefLang()
	{
		$lang = $GLOBALS['liens']->f('entry_lang');
		if (!empty($lang))
			echo ' hreflang="'.$lang.'"';
	}
	
	/**
	@function dirLinkName
	
	Cette fonction affiche le nom d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkName()
	{
		echo $GLOBALS['liens']->f('entry_name');
	}
	
	/**
	@function linkDesc
	
	Cette fonction affiche la description d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkDesc()
	{
		require_once PT_INC_PATH."libs/punbb_parser.php";
		echo parse_message($GLOBALS['liens']->f('entry_description'),false);
	}
	
	/**
	@function linkNbClik
	
	Cette fonction affiche le compteur de cliques d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkNbClik()
	{
		$nb = $GLOBALS['liens']->f('entry_clik');
		
		if ($nb == 0)
			echo __('No click');
			
		elseif ($nb == 1)
			echo __('One click');
			
		elseif ($nb > 1)
			printf(__('%s clicks'),$nb);
	}
	
	/**
	@function linkPr
	
	Cette fonction affiche le PageRank Google d'un site dans le contexte 
	d'une liste de sites.
	
	@param string block 	Masque de formatage du bloc (<p>Google PageRank : %s</p>)
	*/
	function linkPr($block='<p>%s: %s</p>')
	{
		global $liens;
		
		if (pt_mod_directory_google_pr)
		{
			if ($liens->f('entry_pr') == 0)
				printf($block,__('Google Page Rank:'),'n/a');
			else {
				printf($block,__('Google Page Rank:'),'<span class="pageranks pagerank'.$liens->f('entry_pr').'">'.$liens->f('entry_pr').'/10</span>');
			}
		}
	}
	
	/**
	@function linkCat
	
	Cette fonction affiche le nom de la rubrique d'un site dans le contexte 
	d'une liste de sites.
	*/
	function linkCat()
	{
		echo $GLOBALS['arryDirCat'][$GLOBALS['liens']->f('entry_category')];
	}
	
	/**
	@function pageTitre
	
	Affiche le titre de l'une des pages courante de l'annuaire
	*/
	function pageTitre()
	{
		switch ($GLOBALS['dir_mode'])
		{
			case 'toprank':
				echo __('Top Google Page Rank');
				break;
				
			case 'topclick':
				echo __('Top clicks');
				break;
			
			case 'novelties':
				echo __('Novelties');
				break;
		}
	}
	
	/**
	@function pageDesc
	
	Affiche la description de l'une des pages courante de l'annuaire
	*/
	function pageDesc()
	{
		switch ($GLOBALS['dir_mode'])
		{
			case 'toprank':
				printf(__('This page display the %s websites of the directory which have best Google PageRank.'), pt_mod_directory_nb_entry_pr);
				break;
				
			case 'topclick':
				printf(__('This page display the %s websites most visited from the directory.'), pt_mod_directory_nb_entry_tc);
				break;
			
			case 'novelties':
				printf(__('This page display the last %s websites added to the directory.'), pt_mod_directory_nb_entry_new);
				break;
		}
	}
	
	/**
	@function dirAddUrl
	
	Cette fonction affiche l'url de la page de soumission de site.
	*/
	function dirAddUrl()
	{
		echo $GLOBALS['puntal']->url('directory_submit');
	}
	
	/**
	@function selectCat
	
	Cette fonction affiche le menu droulant de choix des rubriques 
	sur la page de soumission de site.
	*/
	function selectCat($f_name='l_cat')
	{
		$rs = '<select name="'.$f_name.'" id="'.$f_name.'">';
		foreach ($GLOBALS['arryDirCat'] as $k=>$v)
		{
			if ($v == $GLOBALS[$f_name])
				$rs .= '<option value="'.$v.'" selected=selected">'.$k.'</option>'."\n";
			else
				$rs .= '<option value="'.$v.'">'.$k.'</option>'."\n";
		}
		$rs .= '</select>';
		
		echo $rs;
	}
	
	/**
	hasErrors<br/>
	
	<strong>FR</strong> Indique si il y a des erreurs.<br/>
	<strong>EN</strong> Tell us if we have errors
	*/
	function hasErrors()
	{
		if (!empty($GLOBALS['errors']))
			return true;
		
		return false;
	}	
	

	/**
	errors<br/>
	
	<strong>FR</strong> Affiche une liste d'erreurs<br/>
	<strong>EN</strong> Display a list of errors 
	*/
	function errors($block='<ul>%s</ul>',$item='<li>%s</li>')
	{
		$items = '';
		foreach ($GLOBALS['errors'] as $err)
			$items .= sprintf($item,$err);
		
		printf($block, $items);
	}
	
	/**
	formValue<br/>
	
	<strong>FR</strong> Affiche un des champs du formulaire.<br/>
	<strong>EN</strong> Display one of the field of the form
	
	@param	var <strong>string</strong	Variable name to be displayed
	*/
	function formValue($var='')
	{
		if ($var == '')
			return;
		
		echo html::escapeHTML($GLOBALS[$var]);
	}	
	
}
?>