<?php
/***********************************************************************

  Copyright (C) 2005-2007 Vincent Garnier and contributors. All rights
  reserved.
  
  This file is part of Puntal 2.

  Puntal 2 is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published
  by the Free Software Foundation; either version 2 of the License,
  or (at your option) any later version.

  Puntal 2 is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, InC., 59 Temple Place, Suite 330, Boston,
  MA  02111-1307  USA

************************************************************************/

if (!defined('PUNTAL')) exit;

/**
	
	@brief downloadManager module class
	
	<strong>FR</strong> La classe de gestion du module Tlchargements<br/>	
	<strong>EN</strong> The class of management of the downloads
*/
class downloadManager
{
	var $url; 						// url du module
	var $path; 						// chemin du module
	var $mode; 						// mode ? redir : send
	var $request; 					// mode ? redir : send
	var $extensions = array();		// liste des extensions autorises
	var $cat_list = array(); 		// liste des catgorie id => name
	var $cat_id_list = array(); 	// liste des id de catgories
	var $cat_id = ''; 				// catgorie courante
	var $fichier = '';				// fichier courant
	var $file_list = array();		// liste des fichiers
	var $file_id = '';				// id fichier courant
	var $title = '';				// titre de la page
	var $content = '';				// contenu html
	var $error; 					// message d'erreur
	var $pt;
    

	/**
	downloadManager<br/>
	
	<strong>FR</strong> Constructeur<br/>
	<strong>EN</strong> Constructor
	
	@param puntal <strong>object</strong> puntal type object
	*/
	function downloadManager(&$puntal)
	{
		$this->pt 			= $puntal;
		$this->pt_dl 		= DB_PREFIX.'pt_downloads';
		$this->pt_dl_cat 	= DB_PREFIX.'pt_downloads_cat';
		$this->url 			= DOWNLOAD_URL;
	}
	
	/**
	checkCat<br/>
	
	<strong>FR</strong> Vrifie l'existence d'une catgorie. Renvoie vrai ou faux.
	<strong>EN</strong> Check that the category exists. Return true or false.
	
	@param	cat_id <strong>integer</strong>	Category ID
	@return	<strong>boolean</strong>
	*/
	function checkCat($cat_id)
	{
		$strReq =
		'SELECT count(id) AS ttl_cat FROM '.$this->pt_dl_cat.' '.
		'WHERE id='.(integer) $cat_id.' ';
		$rs = $this->pt->con->select($strReq);

		if ($rs == false || $rs->f('ttl_cat') == '0')
			return false;
		else
			return true;
	}
	
	/**
	getCat<br/>
	
	<strong>FR</strong>Slectionne une ou plusieurs catgories. La paramtre cat_id peut tre
	un entier, le champ <em>cat_id</em> sera alors pris en compte. S'il s'agit
	d'une chaine, la comparaison sera faite sur <em>cat_url</em>.<br/>
	
	compte galement les fichiers 'actif' d'une catgorie<br/>
	
	Si le paramtre cat_id est une chaine vide, toutes les catgories seront
	renvoyes dans le recordset (fonctionnement par dfaut).<br/>
	
	La mthode renvoie false en cas d'erreur.<br/>
	
	<strong>EN</strong>Select one or several categories. The cat_id parameter may be an integer, the field <em>cat_id</em> will be used.
	If it's a string then the search will be done on <em>cat_url</em>.<br/>
	
	Count also the <em>activated</em> files for a category<br/>
	
	If the parameter cat_id is an empty string, all the categories will be return in the recordset (by default) <br/>
	
	The method returne false in case of error.<br/>	
	
	@param	cat_id <strong>mixed</strong>			Category ID
	@param	order_by <strong>string</strong>		field that sort the results
	@return	rs <strong>object</strong> recordset
	*/
	function getCat($cat_id='',$order_by='C.dl_disp_position')
	{
		$reqPlus = '';
		
		if ($cat_id != '')
		{
			if (preg_match('/^[0-9]+$/',$cat_id))
				$reqPlus .= 'AND C.id='.(integer) $cat_id.' ';
			else
				$reqPlus .= 'AND C.dl_cat_url=\''.$this->pt->con->escapeStr($cat_id).'\' ';
		}
		
		$strReq = 
		'SELECT C.id, C.dl_cat_name, C.dl_cat_url, '.
		'COUNT(F.id) AS nb_files '.
		'FROM '.$this->pt_dl_cat.' C '.
			'LEFT JOIN '.$this->pt_dl.' F ON C.id=F.cat_id AND F.dl_enable=2 '.
		'WHERE 1 '.
		$reqPlus.
		'GROUP BY C.id '.
		'ORDER BY '.$this->pt->con->escapeStr($order_by); 
		
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());

		return $rs;
	}
	
	
	/**
	getFiles<br/>
	
	<strong>FR</strong> cette methode permet de recuperer la liste des fichiers d'une catgorie<br/>
	<strong>EN</strong> this function get the list of all the file for a given category 
	
	@param	cat_id <strong>mixed</strong>			Category ID 
	@return	rs <strong>object</strong> recordset
	*/
	function getFiles($cat_id='')
	{
		global $download_mode;
		
		// on veut un fichier en particulier
		if ($download_mode == 'file' && $cat_id != '') 
		{
			$this->file_id = $cat_id;
			
			$strReq = 
			'SELECT F.id, F.dl_name, F.dl_filename, F.dl_desc, '.
			'F.dl_count, F.dl_date, F.dl_disp_position, F.cat_id, '.
			'C.id AS cid, C.dl_cat_name '.
			'FROM '.$this->pt_dl.' AS F '.
				'INNER JOIN '.$this->pt_dl_cat.' AS C ON C.id=F.cat_id '.
			'WHERE F.id='.(integer) $this->file_id.' AND F.dl_enable=2 '.
			'ORDER BY dl_disp_position';

			$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		}
		
		// on veut une catgorie
		elseif ($download_mode == 'cat' && $cat_id !='') 
		{
			$this->cat_id = $cat_id;
			
			$strReq = 
			'SELECT C.id AS cid, C.dl_cat_name, '.
			'F.id, F.dl_name, F.dl_filename, F.dl_desc, F.dl_date, F.dl_count '.
			'FROM '.$this->pt_dl_cat.' AS C '.
				'INNER JOIN '.$this->pt_dl.' AS F ON C.id=F.cat_id  '.
			'WHERE C.dl_cat_url=\''.$cat_id.'\' AND F.dl_enable=2 '.
			'ORDER BY C.dl_disp_position, F.dl_disp_position';
			
			$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		}
		
		// on veut l'accueil
		elseif ($download_mode == 'home')
		{
			$strReq = 
			'SELECT C.id AS cid, C.dl_cat_name, '.
			'F.id, F.dl_name, F.dl_filename, F.dl_desc, F.dl_date, F.dl_count '.
			'FROM '.$this->pt_dl_cat.' AS C '.
				'INNER JOIN '.$this->pt_dl.' AS F ON C.id=F.cat_id  '.
			'WHERE F.dl_welcome=1 AND F.dl_enable=2 '.
			'ORDER BY C.dl_disp_position, F.dl_disp_position';
			
			$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		}

		return $rs;
	}

	/**
	getFile<br/>
	
	<strong>FR</strong> Rcupration complte d'un fichier donn<br/>
	<strong>EN</strong> Get all info about a given file 
	
	@param	id <strong>integer</strong>			File ID
	@return	rs <strong>object</strong> recordset
	*/	
	function getFile($id='')
	{		
		$id = intval($id);
		if ($id < 1)
		{
			$this->pt->err->setError('Bad argument');
			return false;
		}
		
		$strReq =
		'SELECT F.*, C.dl_cat_name, C.dl_cat_url '.
		'FROM '.$this->pt_dl.' F '.
			'LEFT JOIN '.$this->pt_dl_cat.' C ON F.cat_id=C.id '.
		'WHERE F.id='.(integer) $id.' AND F.dl_enable = \'2\'';
					
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());

		return $rs;
	}


	/**
	downloadFile<br/>
	
	<strong>FR</strong> Fonction de recuperation des infos du fichier donn puis mise  jour du compteur de tlchargement et envoi du fichier au navigateur<br/>
	<strong>EN</strong> Get all info about a given file then update the download counter and send the file to the browser 
	
	@param	id <strong>integer</strong>			File ID

	*/		
	function downloadFile($id)
	{
		// infos fichier
		$strReq =
		'SELECT dl_name, dl_filename, dl_count '.
		'FROM '.$this->pt_dl.' '.
		'WHERE id='.(integer) $id .' AND dl_enable = \'2\'';
		
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		
		if (!$this->pt->con->rowCount($rs))
		{
			$this->error = __('This download not exist.');
			return false;
		}
		
		// chemin du fichier
		$file_path = PUNTAL_ROOT.pt_mod_downloads_path.'/'.$rs->f('dl_filename');
		
		$count = $rs->f('dl_count')+1;
		
		// mise  jour du compteur
		$sql = 
		'UPDATE '.$this->pt_dl.' '.
		'SET dl_count='.(integer) $count.' '.
		'WHERE id='.(integer) $id.' ';
		
		// echo " mode " . pt_mod_downloads_mode;
		$this->pt->con->execute($sql) or $this->pt->err->fatalError($this->pt->con->error());
		
		$this->dlsend($file_path);
	}
	
	
	/**
	dlsend<br/>
	
	<strong>FR</strong> envoi du fichier au navigateur<br/>
	<strong>EN</strong> send the file to the browser 
	
	@param	file_path <strong>string</strong>	path of the file to be send to the browser
	*/
	function dlsend($file_path)
	{
		/*$ofile = fopen($file_path, 'rb'); //Forcage du mode binaire sous windows. CF doc PHP fonction fopen
		$content = fread($ofile, filesize($file_path));
		fclose ($ofile);*/
		header('Content-Transfer-Encoding: none');	// fix un bug pour Opera		
		header('Content-Type: application/octet-stream');
		header('Content-Disposition: attachment; filename="'.basename($file_path) .'"') ;
		header("Content-Length: ".filesize($file_path));
		//echo $content;
		
		$pattern = pt_mod_downloads_path.".*";
        preg_match_all('|'.$pattern.'|', $file_path, $m);

        readfile ($m[0][0]);			
	}
	
	/**
	getLast<br/>
	
	
	<strong>FR</strong> cette methode permet de recuperer la liste des derniers fichiers ajouts<br/>
	<strong>EN</strong> this function get the list of the last added files to be downloaded 
	
	@return	rs <strong>object</strong> recordset
	*/
	function getLast()
	{
		$strReq = 
		'SELECT C.id AS cid, C.dl_cat_name, '.
		'F.id, F.dl_name, F.dl_filename, F.dl_desc, F.dl_date, F.dl_count '.
		'FROM '.$this->pt_dl_cat.' AS C '.
			'INNER JOIN '.$this->pt_dl.' AS F ON C.id=F.cat_id  '.
		'WHERE F.dl_enable=2 '.
		'ORDER BY F.dl_date DESC, C.dl_disp_position, F.dl_disp_position '.
		'LIMIT 0,20';
			
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());
		
		return $rs;
	}	
	
	/**
	getPopular<br/>
	
	
	<strong>FR</strong> cette methode permet de recuperer la liste des fichiers les plus populaires<br/>
	<strong>EN</strong> this function get the list of the most popular files 
	
	@return	rs <strong>object</strong> recordset
	*/	
	function getPopular()
	{
		$strReq = 
		'SELECT C.id AS cid, C.dl_cat_name, '.
		'F.id, F.dl_name, F.dl_filename, F.dl_desc, F.dl_date, F.dl_count '.
		'FROM '.$this->pt_dl_cat.' AS C '.
			'INNER JOIN '.$this->pt_dl.' AS F ON C.id=F.cat_id  '.
		'WHERE F.dl_enable=2 '.
		'ORDER BY F.dl_count DESC, C.dl_disp_position, F.dl_disp_position '.
		'LIMIT 0,20';
			
		$rs = $this->pt->con->select($strReq) or $this->pt->err->fatalError($this->pt->con->error());

		return $rs;
	}	

	/**
	searchEntry<br/>
	
	
	<strong>FR</strong> Recherche d'un fichier selon des mots cl et renvoie un recordset.<br/>Cette fonction est utilise par un callback nomm <strong>searchPerform</strong>
	<strong>EN</strong> Search file by keyword and return the recordset<br/>This function is used by a callback behavior named <strong>searchPerform</strong> 
	
	@param	w <strong>string</strong> Keyword
	@param  limit <strong>string</strong> Limit the number of results to be displayed	
	@return	rs <strong>object</strong> recordset
	*/		
	function searchEntry($w,$limit='')
	{
		$strip = array('+',')','(',',','\'');
		$w = strtolower($w);
		$w = str_replace($strip,' ',$w);
		$w = preg_replace('/( )+/',' ',$w);
		
		$reqPlus = '';
		foreach(explode(' ',$w) as $v)
		{
			$reqPlus .= 
			'AND (LOWER(dl_name) LIKE \'%'.$this->pt->con->escapeStr($v).'%\' OR '.
			'LOWER(dl_desc) LIKE \'%'.$this->pt->con->escapeStr($v).'%\') ';
		}
		
		$sql = 
		'SELECT * FROM '.$this->pt_dl.' WHERE dl_enable = \'2\''. $reqPlus. 'ORDER BY dl_date DESC';
		        
        if ($limit != '')
			$sql = $sql.' LIMIT '.$limit;     
            
		$rs = $this->pt->con->select($sql) or $this->pt->err->fatalError($this->pt->con->error());
		
		return $rs;
	}
    
}

?>
